package com.epson.cameracopy.p006ui;

import android.content.ComponentName;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.ServiceConnection;
import android.content.SharedPreferences;
import android.content.res.Configuration;
import android.os.AsyncTask;
import android.os.Bundle;
import android.os.Handler;
import android.os.IBinder;
import android.os.RemoteException;
import android.os.SystemClock;
import android.view.Menu;
import android.view.MenuItem;
import android.view.MotionEvent;
import android.view.View;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;
import com.epson.mobilephone.common.escpr.EscprError;
import com.epson.mobilephone.common.escpr.MediaInfo;
import com.epson.mobilephone.common.wifidirect.WiFiDirectManager;
import epson.common.Constants;
import epson.common.ExternalFileUtils;
import epson.common.Utils;
import epson.print.ActivityIACommon;

import epson.print.EPPrinterManager;
import epson.print.MyPrinter;
import epson.print.Util.EPLog;
import epson.print.inkrpln.InkRplnRepository;
import epson.print.screen.PageRangeSetting;
import epson.print.screen.PrintProgress;
import epson.print.screen.PrintSetting;
import epson.print.screen.PrinterInfoDetail;
import epson.print.screen.SearchPrinterScr;
import epson.print.service.EpsonService;
import epson.print.service.IEpsonService;
import epson.print.service.IEpsonServiceCallback;
import epson.print.widgets.CustomTitleAlertDialogBuilder;
import epson.print.widgets.LongTapRepeatAdapter;
import java.io.File;
import java.util.ArrayList;

/* renamed from: com.epson.cameracopy.ui.CameraPrintSettingActivity */
public class CameraPrintSettingActivity extends ActivityIACommon implements View.OnClickListener {
    private static final String EXTRA_PRINTER = "myprinter";
    private static final String EXTRA_SIMPLEAP = "simpleap";
    private static final int REQUEST_CODE_INFO = 1;
    private static final int REQUEST_CODE_INK_REPLENISH_PROGRESS = 4;
    private static final int REQUEST_CODE_PAGE_RANGE = 2;
    private static final int REQUEST_CODE_PRINTER = 0;
    public static final String TAG = "CameraPrintSetting";
    private final int COLOR_VALUE_MAX = 50;
    private final int COLOR_VALUE_MIN = -50;
    private final int COPIES_MAX = 30;
    private final int COPIES_MIN = 1;
    private final int EPS_ERR_COMM_ERROR = -1100;
    private final int EPS_ERR_NONE = 0;
    private final int EPS_ERR_OPR_FAIL = -1000;
    private final int EPS_ERR_PRINTER_NOT_SET = EscprError.EPS_ERR_PRINTER_NOT_SET;
    private final int GET_ADVANCED = 64;
    private final int GET_COLOR = 6;
    private final int GET_DUPLEX = 32;
    private final int GET_LAYOUT = 3;
    private final int GET_PAPER_SIZE = 1;
    private final int GET_PAPER_SOURCE = 5;
    private final int GET_PAPER_TYPE = 2;
    private final int GET_QUALITY = 4;
    private final int GET_SUPPORTED_MEDIA = 0;
    private final int PROBE_PRINTER = 17;
    private final int SEARCH_BY_ID = 7;
    private final int SEARCH_ERROR = 16;
    private final int SETTING_DONE = 3;
    private final int SHOW_ERROR_DIALOG = 18;
    private String autoConnectSsid = null;
    private TextView brightness;
    private Button brightnessMinus;
    private Button brightnessPlus;
    private int brightnessValue;
    private int color;
    private TextView colorInfo;
    private int[] color_info = null;
    private TextView contrast;
    private Button contrastMinus;
    private Button contrastPlus;
    private int contrastValue;
    private TextView copies;
    private Button copiesMinus;
    private Button copiesPlus;
    private int copiesValue;
    private boolean disablePrintArea = false;
    private int duplex;
    private TextView duplexInfo;
    private int[] duplex_info = null;
    private boolean enableShowPreview = false;
    private int endValue;
    private int feedDirection;
    private TextView feedDirectionInfo;
    private int[] info = null;
    private boolean isDocumentSetting = true;
    boolean isInfoAvai = false;
    Boolean isNotLoading = true;
    private boolean isRetryAfterConnectSimpleAp = false;
    private boolean isTryConnectSimpleAp = false;
    private int lang = 1;
    private int layout;
    private TextView layoutInfo;
    private int[] layout_info = null;
    private final IEpsonServiceCallback mCallback = new IEpsonServiceCallback.Stub() {
        public void onGetInkState() throws RemoteException {
        }

        public void onGetStatusState() throws RemoteException {
        }

        public void onNotifyEndJob(int i) throws RemoteException {
        }

        public void onNotifyProgress(int i, int i2) throws RemoteException {
        }

        public void onFindPrinterResult(String str, String str2, String str3, String str4, String str5) throws RemoteException {
            String unused = CameraPrintSettingActivity.this.printerIp = str2;
        }

        public void onNotifyContinueable(int i) throws RemoteException {
            EPLog.m313i("IEpsonServiceCallback", "onNotifyContinueable code = " + i);
            if (i == 0) {
                CameraPrintSettingActivity cameraPrintSettingActivity = CameraPrintSettingActivity.this;
                cameraPrintSettingActivity.isInfoAvai = true;
                int unused = cameraPrintSettingActivity.lang = cameraPrintSettingActivity.getPrinterLang();
                CameraPrintSettingActivity cameraPrintSettingActivity2 = CameraPrintSettingActivity.this;
                cameraPrintSettingActivity2.undoFlag = false;
                cameraPrintSettingActivity2.mHandler.sendEmptyMessage(0);
            }
        }

        public void onNotifyError(int i, int i2, boolean z) throws RemoteException {
            EPLog.m313i("IEpsonServiceCallback", "onNotifyError errorCode = " + i2);
            CameraPrintSettingActivity cameraPrintSettingActivity = CameraPrintSettingActivity.this;
            cameraPrintSettingActivity.isInfoAvai = true;
            int unused = cameraPrintSettingActivity.lang = cameraPrintSettingActivity.getPrinterLang();
            CameraPrintSettingActivity cameraPrintSettingActivity2 = CameraPrintSettingActivity.this;
            cameraPrintSettingActivity2.undoFlag = false;
            cameraPrintSettingActivity2.mHandler.sendEmptyMessage(0);
        }
    };
    private final boolean mCameraCopy = true;
    private Context mContext = null;
    private final ServiceConnection mEpsonConnection = new ServiceConnection() {
        public void onServiceDisconnected(ComponentName componentName) {
            EPLog.m316v("SettingScr", "onServiceDisconnected");
            try {
                CameraPrintSettingActivity.this.mEpsonService.unregisterCallback(CameraPrintSettingActivity.this.mCallback);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
            IEpsonService unused = CameraPrintSettingActivity.this.mEpsonService = null;
        }

        public void onServiceConnected(ComponentName componentName, IBinder iBinder) {
            IEpsonService unused = CameraPrintSettingActivity.this.mEpsonService = IEpsonService.Stub.asInterface(iBinder);
            EPLog.m316v("SettingScr", "onServiceConnected");
            if (CameraPrintSettingActivity.this.mEpsonService != null) {
                try {
                    CameraPrintSettingActivity.this.mEpsonService.registerCallback(CameraPrintSettingActivity.this.mCallback);
                } catch (RemoteException e) {
                    e.printStackTrace();
                }
            }
        }
    };
    private IEpsonService mEpsonService = null;
    Handler mHandler = new Handler(new Handler.Callback() {
        /* JADX DEBUG: Multi-variable search result rejected for TypeSearchVarInfo{r1v4, resolved type: boolean} */
        /* JADX WARNING: type inference failed for: r1v1 */
        /* JADX WARNING: type inference failed for: r1v5 */
        /* JADX WARNING: type inference failed for: r1v14, types: [int] */
        /* JADX WARNING: type inference failed for: r1v28 */
        /* JADX WARNING: Multi-variable type inference failed */
        /* JADX WARNING: Removed duplicated region for block: B:156:0x052e  */
        /* JADX WARNING: Removed duplicated region for block: B:159:0x054b  */
        /* JADX WARNING: Removed duplicated region for block: B:163:0x055f  */
        /* JADX WARNING: Removed duplicated region for block: B:171:0x058c  */
        /* JADX WARNING: Removed duplicated region for block: B:175:0x05a4 A[LOOP:6: B:173:0x059e->B:175:0x05a4, LOOP_END] */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        public boolean handleMessage(android.os.Message r15) {
            /*
                r14 = this;
                java.lang.String r0 = "SettingScr"
                java.lang.String r1 = "handleMessage call setScreenState = false"
                epson.print.Util.EPLog.m313i(r0, r1)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r1 = 0
                java.lang.Boolean r2 = java.lang.Boolean.valueOf(r1)
                r0.setScreenState(r2)
                epson.print.screen.PrintSetting r0 = new epson.print.screen.PrintSetting
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                epson.print.screen.PrintSetting$Kind r3 = epson.print.screen.PrintSetting.Kind.cameracopy
                r0.<init>(r2, r3)
                int r2 = r15.what
                r3 = 64
                r4 = 32
                r5 = 0
                r6 = 3
                r7 = 100
                r9 = 2
                r10 = 1
                if (r2 == r4) goto L_0x0b25
                if (r2 == r3) goto L_0x09cd
                r3 = 6
                r11 = 5
                r12 = 4
                r13 = 8
                switch(r2) {
                    case 0: goto L_0x09b0;
                    case 1: goto L_0x0801;
                    case 2: goto L_0x05e8;
                    case 3: goto L_0x0450;
                    case 4: goto L_0x033f;
                    case 5: goto L_0x022c;
                    case 6: goto L_0x012a;
                    default: goto L_0x0032;
                }
            L_0x0032:
                switch(r2) {
                    case 17: goto L_0x00d5;
                    case 18: goto L_0x0067;
                    default: goto L_0x0035;
                }
            L_0x0035:
                java.lang.String r15 = "SettingScr"
                java.lang.String r0 = "default"
                epson.print.Util.EPLog.m313i(r15, r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.widget.TextView r15 = r15.printerName
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r1 = 2131625174(0x7f0e04d6, float:1.8877549E38)
                java.lang.String r0 = r0.getString(r1)
                r15.setText(r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r0 = 2131231128(0x7f080198, float:1.8078328E38)
                android.view.View r15 = r15.findViewById(r0)
                android.widget.ImageView r15 = (android.widget.ImageView) r15
                r15.setVisibility(r13)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                java.lang.Boolean r0 = java.lang.Boolean.valueOf(r10)
                r15.setScreenState(r0)
                goto L_0x0c90
            L_0x0067:
                int r0 = r15.arg1
                r2 = -1100(0xfffffffffffffbb4, float:NaN)
                if (r0 == r2) goto L_0x00b7
                r2 = -1000(0xfffffffffffffc18, float:NaN)
                if (r0 == r2) goto L_0x00b7
                int r15 = r15.arg1
                java.lang.Integer[] r15 = com.epson.mobilephone.common.escpr.MediaInfo.ErrorTable.getStringId(r15)
                if (r15 != 0) goto L_0x0093
                java.lang.Integer[] r15 = new java.lang.Integer[r6]
                r0 = 2131624506(0x7f0e023a, float:1.8876194E38)
                java.lang.Integer r0 = java.lang.Integer.valueOf(r0)
                r15[r1] = r0
                r0 = 2131624507(0x7f0e023b, float:1.8876196E38)
                java.lang.Integer r0 = java.lang.Integer.valueOf(r0)
                r15[r10] = r0
                java.lang.Integer r0 = java.lang.Integer.valueOf(r10)
                r15[r9] = r0
            L_0x0093:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r2 = r15[r10]
                int r2 = r2.intValue()
                java.lang.CharSequence r2 = r0.getText(r2)
                java.lang.String r2 = r2.toString()
                com.epson.cameracopy.ui.CameraPrintSettingActivity r3 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r15 = r15[r1]
                int r15 = r15.intValue()
                java.lang.CharSequence r15 = r3.getText(r15)
                java.lang.String r15 = r15.toString()
                r0.showErrorDialog(r2, r15)
                goto L_0x00ce
            L_0x00b7:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r0 = 2131624778(0x7f0e034a, float:1.8876745E38)
                java.lang.String r15 = r15.getString(r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r1 = 2131624777(0x7f0e0349, float:1.8876743E38)
                java.lang.String r0 = r0.getString(r1)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r1 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r1.showErrorDialog(r15, r0)
            L_0x00ce:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r15.resetSettings()
                goto L_0x0c90
            L_0x00d5:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                epson.print.service.IEpsonService r15 = r15.mEpsonService
                r0 = 17
                if (r15 == 0) goto L_0x0121
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x011b }
                int r15 = r15.printerLocation     // Catch:{ RemoteException -> 0x011b }
                if (r15 == r9) goto L_0x0112
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x011b }
                epson.print.service.IEpsonService r15 = r15.mEpsonService     // Catch:{ RemoteException -> 0x011b }
                com.epson.cameracopy.ui.CameraPrintSettingActivity r1 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x011b }
                java.lang.String r1 = r1.printerId     // Catch:{ RemoteException -> 0x011b }
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x011b }
                java.lang.String r2 = r2.printerIp     // Catch:{ RemoteException -> 0x011b }
                com.epson.cameracopy.ui.CameraPrintSettingActivity r3 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x011b }
                int r3 = r3.printerLocation     // Catch:{ RemoteException -> 0x011b }
                if (r3 != r6) goto L_0x0102
                goto L_0x0103
            L_0x0102:
                r9 = 1
            L_0x0103:
                int r15 = r15.searchPrinters(r1, r2, r9)     // Catch:{ RemoteException -> 0x011b }
                if (r15 == 0) goto L_0x0c90
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x011b }
                android.os.Handler r15 = r15.mHandler     // Catch:{ RemoteException -> 0x011b }
                r15.sendEmptyMessageDelayed(r0, r7)     // Catch:{ RemoteException -> 0x011b }
                goto L_0x0c90
            L_0x0112:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x011b }
                android.os.Handler r15 = r15.mHandler     // Catch:{ RemoteException -> 0x011b }
                r15.sendEmptyMessage(r1)     // Catch:{ RemoteException -> 0x011b }
                goto L_0x0c90
            L_0x011b:
                r15 = move-exception
                r15.printStackTrace()
                goto L_0x0c90
            L_0x0121:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessageDelayed(r0, r7)
                goto L_0x0c90
            L_0x012a:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                epson.print.service.IEpsonService r15 = r15.mEpsonService
                if (r15 != 0) goto L_0x013b
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessageDelayed(r3, r7)
                goto L_0x0c90
            L_0x013b:
                java.lang.String r15 = "SettingScr"
                java.lang.String r0 = "GET_COLOR"
                epson.print.Util.EPLog.m313i(r15, r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] unused = r15.color_info = r5
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x0174 }
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x0174 }
                epson.print.service.IEpsonService r0 = r0.mEpsonService     // Catch:{ RemoteException -> 0x0174 }
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x0174 }
                int r2 = r2.printerLocation     // Catch:{ RemoteException -> 0x0174 }
                if (r2 != r9) goto L_0x0159
                r2 = 1
                goto L_0x015a
            L_0x0159:
                r2 = 0
            L_0x015a:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r3 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x0174 }
                int r3 = r3.mRemoteSrcType     // Catch:{ RemoteException -> 0x0174 }
                com.epson.cameracopy.ui.CameraPrintSettingActivity r5 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x0174 }
                int r5 = r5.sizeIndex     // Catch:{ RemoteException -> 0x0174 }
                com.epson.cameracopy.ui.CameraPrintSettingActivity r6 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x0174 }
                int r6 = r6.typeIndex     // Catch:{ RemoteException -> 0x0174 }
                int[] r0 = r0.getColor(r2, r3, r5, r6)     // Catch:{ RemoteException -> 0x0174 }
                int[] unused = r15.color_info = r0     // Catch:{ RemoteException -> 0x0174 }
                goto L_0x017c
            L_0x0174:
                r15 = move-exception
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r0.undoFlag = r10
                r15.printStackTrace()
            L_0x017c:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.color_info
                if (r15 != 0) goto L_0x0188
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r15.undoFlag = r10
            L_0x0188:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.color_info
                if (r15 == 0) goto L_0x0199
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.color_info
                int r15 = r15.length
                if (r15 > 0) goto L_0x01b0
            L_0x0199:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = new int[r9]
                int[] unused = r15.color_info = r0
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.color_info
                r15[r1] = r1
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.color_info
                r15[r10] = r10
            L_0x01b0:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.color_info
                if (r15 == 0) goto L_0x0c90
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.color_info
                int r15 = r15.length
                if (r15 <= 0) goto L_0x0c90
                r15 = 0
            L_0x01c2:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r0.color_info
                int r0 = r0.length
                if (r15 >= r0) goto L_0x01df
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r0 = r0.color
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r2 = r2.color_info
                r2 = r2[r15]
                if (r0 != r2) goto L_0x01dc
                goto L_0x01df
            L_0x01dc:
                int r15 = r15 + 1
                goto L_0x01c2
            L_0x01df:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r0.color_info
                int r0 = r0.length
                if (r15 < r0) goto L_0x01f3
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r15.color_info
                r0 = r0[r1]
                int unused = r15.color = r0
            L_0x01f3:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$Color r0 = new com.epson.mobilephone.common.escpr.MediaInfo$Color
                r0.<init>()
                com.epson.mobilephone.common.escpr.MediaInfo.AbstractInfo unused = r15.mLookupTable = r0
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.widget.TextView r15 = r15.colorInfo
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r1 = r0.mLookupTable
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r2 = r2.color
                int r1 = r1.getStringId(r2)
                java.lang.String r0 = r0.getString(r1)
                r15.setText(r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r15 = r15.mLookupTable
                r15.destructor()
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessage(r4)
                goto L_0x0c90
            L_0x022c:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                epson.print.service.IEpsonService r15 = r15.mEpsonService
                if (r15 != 0) goto L_0x023d
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessageDelayed(r11, r7)
                goto L_0x0c90
            L_0x023d:
                java.lang.String r15 = "SettingScr"
                java.lang.String r0 = "GET_PAPER_SOURCE"
                epson.print.Util.EPLog.m313i(r15, r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] unused = r15.paper_source_info = r5
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x026b }
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x026b }
                epson.print.service.IEpsonService r0 = r0.mEpsonService     // Catch:{ RemoteException -> 0x026b }
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x026b }
                int r2 = r2.sizeIndex     // Catch:{ RemoteException -> 0x026b }
                com.epson.cameracopy.ui.CameraPrintSettingActivity r4 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x026b }
                int r4 = r4.typeIndex     // Catch:{ RemoteException -> 0x026b }
                com.epson.cameracopy.ui.CameraPrintSettingActivity r5 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x026b }
                int r5 = r5.printerLocation     // Catch:{ RemoteException -> 0x026b }
                int[] r0 = r0.getPaperSource(r2, r4, r5)     // Catch:{ RemoteException -> 0x026b }
                int[] unused = r15.paper_source_info = r0     // Catch:{ RemoteException -> 0x026b }
                goto L_0x0273
            L_0x026b:
                r15 = move-exception
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r0.undoFlag = r10
                r15.printStackTrace()
            L_0x0273:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.paper_source_info
                if (r15 != 0) goto L_0x028e
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r15.undoFlag = r10
                int[] r0 = new int[r10]
                int[] unused = r15.paper_source_info = r0
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.paper_source_info
                r0 = 128(0x80, float:1.794E-43)
                r15[r1] = r0
            L_0x028e:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.paper_source_info
                if (r15 == 0) goto L_0x0c90
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.paper_source_info
                int r15 = r15.length
                if (r15 <= 0) goto L_0x0c90
                r15 = 0
            L_0x02a0:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r0.paper_source_info
                int r0 = r0.length
                if (r15 >= r0) goto L_0x02bd
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r0 = r0.paperSource
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r2 = r2.paper_source_info
                r2 = r2[r15]
                if (r0 != r2) goto L_0x02ba
                goto L_0x02bd
            L_0x02ba:
                int r15 = r15 + 1
                goto L_0x02a0
            L_0x02bd:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r0.paper_source_info
                int r0 = r0.length
                if (r15 < r0) goto L_0x02d1
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r15.paper_source_info
                r0 = r0[r1]
                int unused = r15.paperSource = r0
            L_0x02d1:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int unused = r15.paperSource
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.paper_source_info
                if (r15 == 0) goto L_0x02f8
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.paper_source_info
                int r15 = r15.length
                if (r15 > r10) goto L_0x02f8
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r0 = 2131231313(0x7f080251, float:1.8078703E38)
                android.view.View r15 = r15.findViewById(r0)
                android.widget.ImageView r15 = (android.widget.ImageView) r15
                r15.setVisibility(r13)
                r15 = 128(0x80, float:1.794E-43)
                goto L_0x030c
            L_0x02f8:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r0 = 2131231313(0x7f080251, float:1.8078703E38)
                android.view.View r15 = r15.findViewById(r0)
                android.widget.ImageView r15 = (android.widget.ImageView) r15
                r15.setVisibility(r1)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r15 = r15.paperSource
            L_0x030c:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$PaperSource r1 = new com.epson.mobilephone.common.escpr.MediaInfo$PaperSource
                r1.<init>()
                com.epson.mobilephone.common.escpr.MediaInfo.AbstractInfo unused = r0.mLookupTable = r1
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.widget.TextView r0 = r0.paperSourceInfo
                com.epson.cameracopy.ui.CameraPrintSettingActivity r1 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r2 = r1.mLookupTable
                int r15 = r2.getStringId(r15)
                java.lang.String r15 = r1.getString(r15)
                r0.setText(r15)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r15 = r15.mLookupTable
                r15.destructor()
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessage(r3)
                goto L_0x0c90
            L_0x033f:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                epson.print.service.IEpsonService r15 = r15.mEpsonService
                if (r15 != 0) goto L_0x0350
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessageDelayed(r12, r7)
                goto L_0x0c90
            L_0x0350:
                java.lang.String r15 = "SettingScr"
                java.lang.String r0 = "GET_QUALITY"
                epson.print.Util.EPLog.m313i(r15, r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] unused = r15.info = r5
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x0378 }
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x0378 }
                epson.print.service.IEpsonService r0 = r0.mEpsonService     // Catch:{ RemoteException -> 0x0378 }
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x0378 }
                int r2 = r2.sizeIndex     // Catch:{ RemoteException -> 0x0378 }
                com.epson.cameracopy.ui.CameraPrintSettingActivity r3 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x0378 }
                int r3 = r3.typeIndex     // Catch:{ RemoteException -> 0x0378 }
                int[] r0 = r0.getQuality(r2, r3)     // Catch:{ RemoteException -> 0x0378 }
                int[] unused = r15.info = r0     // Catch:{ RemoteException -> 0x0378 }
                goto L_0x0380
            L_0x0378:
                r15 = move-exception
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r0.undoFlag = r10
                r15.printStackTrace()
            L_0x0380:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.info
                if (r15 != 0) goto L_0x0399
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r15.undoFlag = r10
                int[] r0 = new int[r10]
                int[] unused = r15.info = r0
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.info
                r15[r1] = r9
            L_0x0399:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.info
                if (r15 == 0) goto L_0x0c90
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.info
                int r15 = r15.length
                if (r15 <= 0) goto L_0x0c90
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.info
                int r15 = r15.length
                if (r15 > r10) goto L_0x03c2
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r0 = 2131231394(0x7f0802a2, float:1.8078868E38)
                android.view.View r15 = r15.findViewById(r0)
                android.widget.ImageView r15 = (android.widget.ImageView) r15
                r15.setVisibility(r13)
                goto L_0x03d0
            L_0x03c2:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r0 = 2131231394(0x7f0802a2, float:1.8078868E38)
                android.view.View r15 = r15.findViewById(r0)
                android.widget.ImageView r15 = (android.widget.ImageView) r15
                r15.setVisibility(r1)
            L_0x03d0:
                r15 = 0
            L_0x03d1:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r0.info
                int r0 = r0.length
                if (r15 >= r0) goto L_0x03ee
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r0 = r0.quality
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r2 = r2.info
                r2 = r2[r15]
                if (r0 != r2) goto L_0x03eb
                goto L_0x03ee
            L_0x03eb:
                int r15 = r15 + 1
                goto L_0x03d1
            L_0x03ee:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r0.info
                int r0 = r0.length
                if (r15 < r0) goto L_0x0402
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r15.info
                r0 = r0[r1]
                int unused = r15.quality = r0
            L_0x0402:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r15.info
                int r0 = r0.length
                int[] r0 = new int[r0]
                int[] unused = r15.quality_info = r0
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r15.info
                int[] unused = r15.quality_info = r0
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$Quality r0 = new com.epson.mobilephone.common.escpr.MediaInfo$Quality
                r0.<init>()
                com.epson.mobilephone.common.escpr.MediaInfo.AbstractInfo unused = r15.mLookupTable = r0
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.widget.TextView r15 = r15.qualityInfo
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r1 = r0.mLookupTable
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r2 = r2.quality
                int r1 = r1.getStringId(r2)
                java.lang.String r0 = r0.getString(r1)
                r15.setText(r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r15 = r15.mLookupTable
                r15.destructor()
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessage(r11)
                goto L_0x0c90
            L_0x0450:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                epson.print.service.IEpsonService r15 = r15.mEpsonService
                if (r15 != 0) goto L_0x0461
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessageDelayed(r6, r7)
                goto L_0x0c90
            L_0x0461:
                java.lang.String r15 = "SettingScr"
                java.lang.String r0 = "GET_LAYOUT"
                epson.print.Util.EPLog.m313i(r15, r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] unused = r15.info = r5
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x0489 }
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x0489 }
                epson.print.service.IEpsonService r0 = r0.mEpsonService     // Catch:{ RemoteException -> 0x0489 }
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x0489 }
                int r2 = r2.sizeIndex     // Catch:{ RemoteException -> 0x0489 }
                com.epson.cameracopy.ui.CameraPrintSettingActivity r3 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x0489 }
                int r3 = r3.typeIndex     // Catch:{ RemoteException -> 0x0489 }
                int[] r0 = r0.getLayout(r2, r3)     // Catch:{ RemoteException -> 0x0489 }
                int[] unused = r15.info = r0     // Catch:{ RemoteException -> 0x0489 }
                goto L_0x0491
            L_0x0489:
                r15 = move-exception
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r0.undoFlag = r10
                r15.printStackTrace()
            L_0x0491:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                boolean unused = r15.isDocumentSetting
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.info
                if (r15 != 0) goto L_0x04b2
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r15.undoFlag = r10
                int[] r15 = r15.info
                if (r15 != 0) goto L_0x04b2
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = new int[r9]
                r0 = {2, 1} // fill-array
                int[] unused = r15.info = r0
            L_0x04b2:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.info
                if (r15 == 0) goto L_0x0c90
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.info
                int r15 = r15.length
                if (r15 <= 0) goto L_0x0c90
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.info
                int r15 = r15.length
                if (r15 > r10) goto L_0x04db
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r0 = 2131231162(0x7f0801ba, float:1.8078397E38)
                android.view.View r15 = r15.findViewById(r0)
                android.widget.ImageView r15 = (android.widget.ImageView) r15
                r15.setVisibility(r13)
                goto L_0x04e9
            L_0x04db:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r0 = 2131231162(0x7f0801ba, float:1.8078397E38)
                android.view.View r15 = r15.findViewById(r0)
                android.widget.ImageView r15 = (android.widget.ImageView) r15
                r15.setVisibility(r1)
            L_0x04e9:
                r15 = 0
            L_0x04ea:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r0.info
                int r0 = r0.length
                if (r15 >= r0) goto L_0x0525
                java.lang.String r0 = "layout info"
                java.lang.StringBuilder r2 = new java.lang.StringBuilder
                r2.<init>()
                java.lang.String r3 = "layout info "
                r2.append(r3)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r3 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r3 = r3.info
                r3 = r3[r15]
                r2.append(r3)
                java.lang.String r2 = r2.toString()
                epson.print.Util.EPLog.m316v(r0, r2)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r0 = r0.layout
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r2 = r2.info
                r2 = r2[r15]
                if (r0 != r2) goto L_0x0522
                goto L_0x0525
            L_0x0522:
                int r15 = r15 + 1
                goto L_0x04ea
            L_0x0525:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r0.info
                int r0 = r0.length
                if (r15 < r0) goto L_0x0539
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r15.info
                r0 = r0[r1]
                int unused = r15.layout = r0
            L_0x0539:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$Layout r0 = new com.epson.mobilephone.common.escpr.MediaInfo$Layout
                r0.<init>()
                com.epson.mobilephone.common.escpr.MediaInfo.AbstractInfo unused = r15.mLookupTable = r0
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r15 = r15.layout
                if (r15 != r13) goto L_0x0550
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int unused = r15.layout = r9
            L_0x0550:
                java.util.ArrayList r15 = new java.util.ArrayList
                r15.<init>()
                r0 = 0
            L_0x0556:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r2 = r2.info
                int r2 = r2.length
                if (r0 >= r2) goto L_0x057b
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r2 = r2.info
                r2 = r2[r0]
                if (r2 == r13) goto L_0x0578
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r2 = r2.info
                r2 = r2[r0]
                java.lang.Integer r2 = java.lang.Integer.valueOf(r2)
                r15.add(r2)
            L_0x0578:
                int r0 = r0 + 1
                goto L_0x0556
            L_0x057b:
                java.lang.Integer r0 = java.lang.Integer.valueOf(r12)
                boolean r0 = r15.remove(r0)
                if (r0 == 0) goto L_0x0586
                goto L_0x057b
            L_0x0586:
                int r0 = r15.size()
                if (r0 != 0) goto L_0x0593
                java.lang.Integer r0 = java.lang.Integer.valueOf(r9)
                r15.add(r0)
            L_0x0593:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r2 = r15.size()
                int[] r2 = new int[r2]
                int[] unused = r0.layout_info = r2
            L_0x059e:
                int r0 = r15.size()
                if (r1 >= r0) goto L_0x05b9
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r0.layout_info
                java.lang.Object r2 = r15.get(r1)
                java.lang.Integer r2 = (java.lang.Integer) r2
                int r2 = r2.intValue()
                r0[r1] = r2
                int r1 = r1 + 1
                goto L_0x059e
            L_0x05b9:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.widget.TextView r15 = r15.layoutInfo
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r1 = r0.mLookupTable
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r2 = r2.layout
                int r1 = r1.getStringId(r2)
                java.lang.String r0 = r0.getString(r1)
                r15.setText(r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r15 = r15.mLookupTable
                r15.destructor()
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessage(r12)
                goto L_0x0c90
            L_0x05e8:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                epson.print.service.IEpsonService r15 = r15.mEpsonService
                if (r15 != 0) goto L_0x05f9
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessageDelayed(r9, r7)
                goto L_0x0c90
            L_0x05f9:
                java.lang.String r15 = "SettingScr"
                java.lang.String r2 = "GET_PAPER_TYPE"
                epson.print.Util.EPLog.m313i(r15, r2)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] unused = r15.info = r5
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x061b }
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x061b }
                epson.print.service.IEpsonService r2 = r2.mEpsonService     // Catch:{ RemoteException -> 0x061b }
                com.epson.cameracopy.ui.CameraPrintSettingActivity r3 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x061b }
                int r3 = r3.sizeIndex     // Catch:{ RemoteException -> 0x061b }
                int[] r2 = r2.getPaperType(r3)     // Catch:{ RemoteException -> 0x061b }
                int[] unused = r15.info = r2     // Catch:{ RemoteException -> 0x061b }
                goto L_0x0623
            L_0x061b:
                r15 = move-exception
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r2.undoFlag = r10
                r15.printStackTrace()
            L_0x0623:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r2 = r15.info
                int[] r2 = r14.removeCddvdMedia(r2)
                int[] unused = r15.info = r2
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.info
                if (r15 != 0) goto L_0x0659
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r15.undoFlag = r10
                int[] r15 = r15.info
                if (r15 != 0) goto L_0x0659
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r2 = new int[r9]
                com.epson.mobilephone.common.PrintingLib.define.Constants$MediaName r3 = com.epson.mobilephone.common.PrintingLib.define.Constants.MediaName.EPS_MTID_PLAIN
                int r3 = r3.getCode()
                r2[r1] = r3
                com.epson.mobilephone.common.PrintingLib.define.Constants$MediaName r3 = com.epson.mobilephone.common.PrintingLib.define.Constants.MediaName.EPS_MTID_PGPHOTO
                int r3 = r3.getCode()
                r2[r10] = r3
                int[] unused = r15.info = r2
            L_0x0659:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.info
                if (r15 == 0) goto L_0x0c90
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.info
                int r15 = r15.length
                if (r15 <= 0) goto L_0x0c90
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.info
                int r15 = r15.length
                if (r15 > r10) goto L_0x0682
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r2 = 2131231316(0x7f080254, float:1.807871E38)
                android.view.View r15 = r15.findViewById(r2)
                android.widget.ImageView r15 = (android.widget.ImageView) r15
                r15.setVisibility(r13)
                goto L_0x0690
            L_0x0682:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r2 = 2131231316(0x7f080254, float:1.807871E38)
                android.view.View r15 = r15.findViewById(r2)
                android.widget.ImageView r15 = (android.widget.ImageView) r15
                r15.setVisibility(r1)
            L_0x0690:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int unused = r15.typeIndex = r1
            L_0x0695:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r15 = r15.typeIndex
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r2 = r2.info
                int r2 = r2.length
                if (r15 >= r2) goto L_0x06c1
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r15 = r15.paperType
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r2 = r2.info
                com.epson.cameracopy.ui.CameraPrintSettingActivity r3 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r3 = r3.typeIndex
                r2 = r2[r3]
                if (r15 != r2) goto L_0x06bb
                goto L_0x06c1
            L_0x06bb:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.cameracopy.p006ui.CameraPrintSettingActivity.access$1608(r15)
                goto L_0x0695
            L_0x06c1:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r15 = r15.typeIndex
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r2 = r2.info
                int r2 = r2.length
                if (r15 < r2) goto L_0x0704
                int r15 = r0.getDefaultPaperType()
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int unused = r0.typeIndex = r1
            L_0x06d9:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r0 = r0.typeIndex
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r2 = r2.info
                int r2 = r2.length
                if (r0 >= r2) goto L_0x0704
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r0.info
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r2 = r2.typeIndex
                r0 = r0[r2]
                if (r15 != r0) goto L_0x06fe
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int unused = r0.paperType = r15
                goto L_0x0704
            L_0x06fe:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.cameracopy.p006ui.CameraPrintSettingActivity.access$1608(r0)
                goto L_0x06d9
            L_0x0704:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r15 = r15.typeIndex
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r0.info
                int r0 = r0.length
                if (r15 < r0) goto L_0x078e
                com.epson.mobilephone.common.PrintingLib.define.Constants$MediaName r15 = com.epson.mobilephone.common.PrintingLib.define.Constants.MediaName.EPS_MTID_PLAIN1
                int r15 = r15.getCode()
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int unused = r0.typeIndex = r1
            L_0x071e:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r0 = r0.typeIndex
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r2 = r2.info
                int r2 = r2.length
                if (r0 >= r2) goto L_0x0749
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r0.info
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r2 = r2.typeIndex
                r0 = r0[r2]
                if (r15 != r0) goto L_0x0743
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int unused = r0.paperType = r15
                goto L_0x0749
            L_0x0743:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.cameracopy.p006ui.CameraPrintSettingActivity.access$1608(r0)
                goto L_0x071e
            L_0x0749:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r15 = r15.typeIndex
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r0.info
                int r0 = r0.length
                if (r15 < r0) goto L_0x078e
                com.epson.mobilephone.common.PrintingLib.define.Constants$MediaName r15 = com.epson.mobilephone.common.PrintingLib.define.Constants.MediaName.EPS_MTID_AUTO_PLAIN
                int r15 = r15.getCode()
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int unused = r0.typeIndex = r1
            L_0x0763:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r0 = r0.typeIndex
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r2 = r2.info
                int r2 = r2.length
                if (r0 >= r2) goto L_0x078e
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r0.info
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r2 = r2.typeIndex
                r0 = r0[r2]
                if (r15 != r0) goto L_0x0788
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int unused = r0.paperType = r15
                goto L_0x078e
            L_0x0788:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.cameracopy.p006ui.CameraPrintSettingActivity.access$1608(r0)
                goto L_0x0763
            L_0x078e:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r15 = r15.typeIndex
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r0.info
                int r0 = r0.length
                if (r15 < r0) goto L_0x07b3
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int unused = r15.typeIndex = r1
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r15.info
                com.epson.cameracopy.ui.CameraPrintSettingActivity r1 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r1 = r1.typeIndex
                r0 = r0[r1]
                int unused = r15.paperType = r0
            L_0x07b3:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r15.info
                int r0 = r0.length
                int[] r0 = new int[r0]
                int[] unused = r15.paper_type_info = r0
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r15.info
                int[] unused = r15.paper_type_info = r0
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$PaperType r0 = new com.epson.mobilephone.common.escpr.MediaInfo$PaperType
                r0.<init>()
                com.epson.mobilephone.common.escpr.MediaInfo.AbstractInfo unused = r15.mLookupTable = r0
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.widget.TextView r15 = r15.paperTypeInfo
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r1 = r0.mLookupTable
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r2 = r2.paperType
                int r1 = r1.getStringId(r2)
                java.lang.String r0 = r0.getString(r1)
                r15.setText(r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r15 = r15.mLookupTable
                r15.destructor()
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessage(r6)
                goto L_0x0c90
            L_0x0801:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                epson.print.service.IEpsonService r15 = r15.mEpsonService
                if (r15 != 0) goto L_0x0812
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessageDelayed(r10, r7)
                goto L_0x0c90
            L_0x0812:
                java.lang.String r15 = "SettingScr"
                java.lang.String r2 = "GET_PAPER_SIZE"
                epson.print.Util.EPLog.m313i(r15, r2)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] unused = r15.info = r5
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x082e }
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x082e }
                epson.print.service.IEpsonService r2 = r2.mEpsonService     // Catch:{ RemoteException -> 0x082e }
                int[] r2 = r2.getPaperSize()     // Catch:{ RemoteException -> 0x082e }
                int[] unused = r15.info = r2     // Catch:{ RemoteException -> 0x082e }
                goto L_0x0836
            L_0x082e:
                r15 = move-exception
                r15.printStackTrace()
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r15.undoFlag = r10
            L_0x0836:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.info
                if (r15 != 0) goto L_0x0892
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r15.undoFlag = r10
                r2 = 9
                int[] r2 = new int[r2]
                com.epson.mobilephone.common.PrintingLib.define.Constants$PaperName r4 = com.epson.mobilephone.common.PrintingLib.define.Constants.PaperName.EPS_MSID_A4
                int r4 = r4.getCode()
                r2[r1] = r4
                com.epson.mobilephone.common.PrintingLib.define.Constants$PaperName r4 = com.epson.mobilephone.common.PrintingLib.define.Constants.PaperName.EPS_MSID_A3
                int r4 = r4.getCode()
                r2[r10] = r4
                com.epson.mobilephone.common.PrintingLib.define.Constants$PaperName r4 = com.epson.mobilephone.common.PrintingLib.define.Constants.PaperName.EPS_MSID_B4
                int r4 = r4.getCode()
                r2[r9] = r4
                com.epson.mobilephone.common.PrintingLib.define.Constants$PaperName r4 = com.epson.mobilephone.common.PrintingLib.define.Constants.PaperName.EPS_MSID_B5
                int r4 = r4.getCode()
                r2[r6] = r4
                com.epson.mobilephone.common.PrintingLib.define.Constants$PaperName r4 = com.epson.mobilephone.common.PrintingLib.define.Constants.PaperName.EPS_MSID_LETTER
                int r4 = r4.getCode()
                r2[r12] = r4
                com.epson.mobilephone.common.PrintingLib.define.Constants$PaperName r4 = com.epson.mobilephone.common.PrintingLib.define.Constants.PaperName.EPS_MSID_LEGAL
                int r4 = r4.getCode()
                r2[r11] = r4
                com.epson.mobilephone.common.PrintingLib.define.Constants$PaperName r4 = com.epson.mobilephone.common.PrintingLib.define.Constants.PaperName.EPS_MSID_POSTCARD
                int r4 = r4.getCode()
                r2[r3] = r4
                r3 = 7
                com.epson.mobilephone.common.PrintingLib.define.Constants$PaperName r4 = com.epson.mobilephone.common.PrintingLib.define.Constants.PaperName.EPS_MSID_4X6
                int r4 = r4.getCode()
                r2[r3] = r4
                com.epson.mobilephone.common.PrintingLib.define.Constants$PaperName r3 = com.epson.mobilephone.common.PrintingLib.define.Constants.PaperName.EPS_MSID_L
                int r3 = r3.getCode()
                r2[r13] = r3
                int[] unused = r15.info = r2
            L_0x0892:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.info
                if (r15 == 0) goto L_0x0c90
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.info
                int r15 = r15.length
                if (r15 <= 0) goto L_0x0c90
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.info
                int r15 = r15.length
                if (r15 > r10) goto L_0x08bb
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r2 = 2131231309(0x7f08024d, float:1.8078695E38)
                android.view.View r15 = r15.findViewById(r2)
                android.widget.ImageView r15 = (android.widget.ImageView) r15
                r15.setVisibility(r13)
                goto L_0x08c9
            L_0x08bb:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r2 = 2131231309(0x7f08024d, float:1.8078695E38)
                android.view.View r15 = r15.findViewById(r2)
                android.widget.ImageView r15 = (android.widget.ImageView) r15
                r15.setVisibility(r1)
            L_0x08c9:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int unused = r15.sizeIndex = r1
            L_0x08ce:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r15 = r15.sizeIndex
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r2 = r2.info
                int r2 = r2.length
                if (r15 >= r2) goto L_0x08fa
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r15 = r15.paperSize
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r2 = r2.info
                com.epson.cameracopy.ui.CameraPrintSettingActivity r3 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r3 = r3.sizeIndex
                r2 = r2[r3]
                if (r15 != r2) goto L_0x08f4
                goto L_0x08fa
            L_0x08f4:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.cameracopy.p006ui.CameraPrintSettingActivity.access$1108(r15)
                goto L_0x08ce
            L_0x08fa:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r15 = r15.sizeIndex
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r2 = r2.info
                int r2 = r2.length
                if (r15 < r2) goto L_0x093d
                int r15 = r0.getDefaultPaperSize()
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int unused = r0.sizeIndex = r1
            L_0x0912:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r0 = r0.sizeIndex
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r2 = r2.info
                int r2 = r2.length
                if (r0 >= r2) goto L_0x093d
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r0.info
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r2 = r2.sizeIndex
                r0 = r0[r2]
                if (r15 != r0) goto L_0x0937
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int unused = r0.paperSize = r15
                goto L_0x093d
            L_0x0937:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.cameracopy.p006ui.CameraPrintSettingActivity.access$1108(r0)
                goto L_0x0912
            L_0x093d:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r15 = r15.sizeIndex
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r0.info
                int r0 = r0.length
                if (r15 < r0) goto L_0x0962
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int unused = r15.sizeIndex = r1
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r15.info
                com.epson.cameracopy.ui.CameraPrintSettingActivity r1 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r1 = r1.sizeIndex
                r0 = r0[r1]
                int unused = r15.paperSize = r0
            L_0x0962:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r15.info
                int r0 = r0.length
                int[] r0 = new int[r0]
                int[] unused = r15.paper_size_info = r0
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r15.info
                int[] unused = r15.paper_size_info = r0
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$PaperSize r0 = new com.epson.mobilephone.common.escpr.MediaInfo$PaperSize
                r0.<init>()
                com.epson.mobilephone.common.escpr.MediaInfo.AbstractInfo unused = r15.mLookupTable = r0
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.widget.TextView r15 = r15.paperSizeInfo
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r1 = r0.mLookupTable
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r2 = r2.paperSize
                int r1 = r1.getStringId(r2)
                java.lang.String r0 = r0.getString(r1)
                r15.setText(r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r15 = r15.mLookupTable
                r15.destructor()
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessage(r9)
                goto L_0x0c90
            L_0x09b0:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                epson.print.service.IEpsonService r15 = r15.mEpsonService
                if (r15 == 0) goto L_0x09c4
                com.epson.cameracopy.ui.CameraPrintSettingActivity$3$1 r15 = new com.epson.cameracopy.ui.CameraPrintSettingActivity$3$1
                r15.<init>()
                java.lang.Void[] r0 = new java.lang.Void[r1]
                r15.execute(r0)
                goto L_0x0c90
            L_0x09c4:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessageDelayed(r1, r7)
                goto L_0x0c90
            L_0x09cd:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r0 = 2131231301(0x7f080245, float:1.807868E38)
                android.view.View r15 = r15.findViewById(r0)
                android.widget.TextView r15 = (android.widget.TextView) r15
                java.lang.StringBuilder r0 = new java.lang.StringBuilder
                r0.<init>()
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r2 = r2.startValue
                r0.append(r2)
                java.lang.String r2 = ".."
                r0.append(r2)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r2 = r2.endValue
                r0.append(r2)
                java.lang.String r0 = r0.toString()
                r15.setText(r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$FeedDirection r0 = new com.epson.mobilephone.common.escpr.MediaInfo$FeedDirection
                r0.<init>()
                com.epson.mobilephone.common.escpr.MediaInfo.AbstractInfo unused = r15.mLookupTable = r0
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.widget.TextView r15 = r15.feedDirectionInfo
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r2 = r0.mLookupTable
                com.epson.cameracopy.ui.CameraPrintSettingActivity r3 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r3 = r3.feedDirection
                int r2 = r2.getStringId(r3)
                java.lang.String r0 = r0.getString(r2)
                r15.setText(r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r15 = r15.mLookupTable
                r15.destructor()
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$PrintDate r0 = new com.epson.mobilephone.common.escpr.MediaInfo$PrintDate
                r0.<init>()
                com.epson.mobilephone.common.escpr.MediaInfo.AbstractInfo unused = r15.mLookupTable = r0
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.widget.TextView r15 = r15.printDateInfo
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r2 = r0.mLookupTable
                com.epson.cameracopy.ui.CameraPrintSettingActivity r3 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r3 = r3.printdate
                int r2 = r2.getStringId(r3)
                java.lang.String r0 = r0.getString(r2)
                r15.setText(r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r15 = r15.mLookupTable
                r15.destructor()
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.widget.TextView r15 = r15.brightness
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r0 = r0.brightnessValue
                java.lang.String r0 = java.lang.String.valueOf(r0)
                r15.setText(r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.widget.Button r15 = r15.brightnessMinus
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r0 = r0.brightnessValue
                r2 = -50
                if (r0 == r2) goto L_0x0a80
                r0 = 1
                goto L_0x0a81
            L_0x0a80:
                r0 = 0
            L_0x0a81:
                r15.setEnabled(r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.widget.Button r15 = r15.brightnessPlus
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r0 = r0.brightnessValue
                r3 = 50
                if (r0 == r3) goto L_0x0a96
                r0 = 1
                goto L_0x0a97
            L_0x0a96:
                r0 = 0
            L_0x0a97:
                r15.setEnabled(r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.widget.TextView r15 = r15.contrast
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r0 = r0.contrastValue
                java.lang.String r0 = java.lang.String.valueOf(r0)
                r15.setText(r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.widget.Button r15 = r15.contrastMinus
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r0 = r0.contrastValue
                if (r0 == r2) goto L_0x0abd
                r0 = 1
                goto L_0x0abe
            L_0x0abd:
                r0 = 0
            L_0x0abe:
                r15.setEnabled(r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.widget.Button r15 = r15.contrastPlus
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r0 = r0.contrastValue
                if (r0 == r3) goto L_0x0ad1
                r0 = 1
                goto L_0x0ad2
            L_0x0ad1:
                r0 = 0
            L_0x0ad2:
                r15.setEnabled(r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.widget.TextView r15 = r15.saturation
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r0 = r0.saturationValue
                java.lang.String r0 = java.lang.String.valueOf(r0)
                r15.setText(r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.widget.Button r15 = r15.saturationMinus
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r0 = r0.saturationValue
                if (r0 == r2) goto L_0x0af8
                r0 = 1
                goto L_0x0af9
            L_0x0af8:
                r0 = 0
            L_0x0af9:
                r15.setEnabled(r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.widget.Button r15 = r15.saturationPlus
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r0 = r0.saturationValue
                if (r0 == r3) goto L_0x0b0b
                r1 = 1
            L_0x0b0b:
                r15.setEnabled(r1)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r15.updateSettingView()
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                java.lang.Boolean r0 = java.lang.Boolean.valueOf(r10)
                r15.setScreenState(r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                boolean r0 = r15.undoFlag
                boolean unused = r15.updateSupportedMediaFile(r0)
                goto L_0x0c90
            L_0x0b25:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                epson.print.service.IEpsonService r15 = r15.mEpsonService
                if (r15 != 0) goto L_0x0b36
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessageDelayed(r4, r7)
                goto L_0x0c90
            L_0x0b36:
                java.lang.String r15 = "SettingScr"
                java.lang.String r0 = "GET_DUPLEX"
                epson.print.Util.EPLog.m313i(r15, r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] unused = r15.duplex_info = r5
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x0b59 }
                epson.print.service.IEpsonService r15 = r15.mEpsonService     // Catch:{ RemoteException -> 0x0b59 }
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x0b59 }
                int r0 = r0.sizeIndex     // Catch:{ RemoteException -> 0x0b59 }
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this     // Catch:{ RemoteException -> 0x0b59 }
                int r2 = r2.typeIndex     // Catch:{ RemoteException -> 0x0b59 }
                int r15 = r15.getDuplex(r0, r2)     // Catch:{ RemoteException -> 0x0b59 }
                goto L_0x0b62
            L_0x0b59:
                r15 = move-exception
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                r0.undoFlag = r10
                r15.printStackTrace()
                r15 = 0
            L_0x0b62:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                java.lang.String r0 = r0.printerId
                if (r0 != 0) goto L_0x0b99
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r0 = r0.paperType
                com.epson.mobilephone.common.PrintingLib.define.Constants$MediaName r2 = com.epson.mobilephone.common.PrintingLib.define.Constants.MediaName.EPS_MTID_PLAIN
                int r2 = r2.getCode()
                if (r0 != r2) goto L_0x0b99
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = new int[r6]
                int[] unused = r15.duplex_info = r0
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.duplex_info
                r15[r1] = r1
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.duplex_info
                r15[r10] = r10
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.duplex_info
                r15[r9] = r9
                goto L_0x0c0f
            L_0x0b99:
                if (r15 == 0) goto L_0x0c00
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r0 = r0.paperSource
                r2 = 16
                if (r0 == r2) goto L_0x0c00
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r0 = r0.layout
                if (r0 != r10) goto L_0x0be0
                r15 = r15 & r9
                if (r15 == 0) goto L_0x0bd0
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = new int[r6]
                int[] unused = r15.duplex_info = r0
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.duplex_info
                r15[r1] = r1
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.duplex_info
                r15[r10] = r10
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.duplex_info
                r15[r9] = r9
                goto L_0x0c0f
            L_0x0bd0:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = new int[r10]
                int[] unused = r15.duplex_info = r0
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.duplex_info
                r15[r1] = r1
                goto L_0x0c0f
            L_0x0be0:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = new int[r6]
                int[] unused = r15.duplex_info = r0
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.duplex_info
                r15[r1] = r1
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.duplex_info
                r15[r10] = r10
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.duplex_info
                r15[r9] = r9
                goto L_0x0c0f
            L_0x0c00:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = new int[r10]
                int[] unused = r15.duplex_info = r0
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.duplex_info
                r15[r1] = r1
            L_0x0c0f:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.duplex_info
                if (r15 == 0) goto L_0x0c82
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r15 = r15.duplex_info
                int r15 = r15.length
                if (r15 <= 0) goto L_0x0c82
                r15 = 0
            L_0x0c21:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r0.duplex_info
                int r0 = r0.length
                if (r15 >= r0) goto L_0x0c3e
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r0 = r0.duplex
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r2 = r2.duplex_info
                r2 = r2[r15]
                if (r0 != r2) goto L_0x0c3b
                goto L_0x0c3e
            L_0x0c3b:
                int r15 = r15 + 1
                goto L_0x0c21
            L_0x0c3e:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r0.duplex_info
                int r0 = r0.length
                if (r15 < r0) goto L_0x0c52
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int[] r0 = r15.duplex_info
                r0 = r0[r1]
                int unused = r15.duplex = r0
            L_0x0c52:
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$Duplex r0 = new com.epson.mobilephone.common.escpr.MediaInfo$Duplex
                r0.<init>()
                com.epson.mobilephone.common.escpr.MediaInfo.AbstractInfo unused = r15.mLookupTable = r0
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.widget.TextView r15 = r15.duplexInfo
                com.epson.cameracopy.ui.CameraPrintSettingActivity r0 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r1 = r0.mLookupTable
                com.epson.cameracopy.ui.CameraPrintSettingActivity r2 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                int r2 = r2.duplex
                int r1 = r1.getStringId(r2)
                java.lang.String r0 = r0.getString(r1)
                r15.setText(r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                com.epson.mobilephone.common.escpr.MediaInfo$AbstractInfo r15 = r15.mLookupTable
                r15.destructor()
            L_0x0c82:
                java.lang.String r15 = "SettingScr"
                java.lang.String r0 = "get Color setScreenState = true"
                epson.print.Util.EPLog.m313i(r15, r0)
                com.epson.cameracopy.ui.CameraPrintSettingActivity r15 = com.epson.cameracopy.p006ui.CameraPrintSettingActivity.this
                android.os.Handler r15 = r15.mHandler
                r15.sendEmptyMessage(r3)
            L_0x0c90:
                return r10
            */
            throw new UnsupportedOperationException("Method not decompiled: com.epson.cameracopy.p006ui.CameraPrintSettingActivity.C08553.handleMessage(android.os.Message):boolean");
        }

        private int[] removeCddvdMedia(int[] iArr) {
            if (iArr == null) {
                return null;
            }
            ArrayList arrayList = new ArrayList();
            for (int valueOf : iArr) {
                arrayList.add(Integer.valueOf(valueOf));
            }
            for (Integer remove : new Integer[]{91, 92, 93}) {
                do {
                } while (arrayList.remove(remove));
            }
            int[] iArr2 = new int[arrayList.size()];
            for (int i = 0; i < arrayList.size(); i++) {
                iArr2[i] = ((Integer) arrayList.get(i)).intValue();
            }
            return iArr2;
        }
    });
    private MediaInfo.AbstractInfo mLookupTable;
    private MediaInfo.AbstractInfo mPaperSizeType;
    private boolean mPrinterSelectDone;
    private int mRemoteSrcType;
    private boolean mWaiteInkReplenProgress;
    private int paperSize;
    private TextView paperSizeInfo;
    private int paperSource;
    private TextView paperSourceInfo;
    private int paperType;
    private TextView paperTypeInfo;
    private int[] paper_size_info = null;
    private int[] paper_source_info = null;
    private int[] paper_type_info = null;
    private boolean printAll;
    private TextView printDateInfo;
    private int printdate;
    private MyPrinter printer = null;
    private String printerDeviceId;
    private String printerEmailAddress;
    private String printerId;
    private String printerIp;
    private int printerLocation;
    private TextView printerName;
    private String printerSerialNo;
    private View progressGetOption;
    private int quality;
    private TextView qualityInfo;
    private int[] quality_info = null;
    private TextView saturation;
    private Button saturationMinus;
    private Button saturationPlus;
    private int saturationValue;
    private int sheets = 1;
    private int sizeIndex = 0;
    private int startValue;
    private int typeIndex = 0;
    boolean undoFlag = true;

    static /* synthetic */ int access$1108(CameraPrintSettingActivity cameraPrintSettingActivity) {
        int i = cameraPrintSettingActivity.sizeIndex;
        cameraPrintSettingActivity.sizeIndex = i + 1;
        return i;
    }

    static /* synthetic */ int access$1608(CameraPrintSettingActivity cameraPrintSettingActivity) {
        int i = cameraPrintSettingActivity.typeIndex;
        cameraPrintSettingActivity.typeIndex = i + 1;
        return i;
    }

    protected void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        setContentView((int) R.layout.setting_layout);
        setActionBar((int) R.string.str_btn_printer_settings, true);
        bindEpsonService();
        this.mContext = this;
        this.mRemoteSrcType = 2;
        this.isDocumentSetting = getIntent().getBooleanExtra(PrintProgress.PARAM_DOCUMENT_MODE, false);
        if (this.isDocumentSetting) {
            this.sheets = getIntent().getIntExtra("SHEETS", 1);
            this.disablePrintArea = getIntent().getBooleanExtra("PRINTAREA", false);
            this.mRemoteSrcType = 1;
        }
        this.sheets = 1;
        this.mRemoteSrcType = 2;
        this.printerName = (TextView) findViewById(R.id.printer_name);
        this.paperSizeInfo = (TextView) findViewById(R.id.paper_size_info);
        this.paperTypeInfo = (TextView) findViewById(R.id.paper_type_info);
        this.layoutInfo = (TextView) findViewById(R.id.layout_info);
        this.qualityInfo = (TextView) findViewById(R.id.quality_info);
        this.paperSourceInfo = (TextView) findViewById(R.id.paper_source_info);
        this.copies = (TextView) findViewById(R.id.copies);
        this.copiesMinus = (Button) findViewById(R.id.copies_minus_button);
        this.copiesPlus = (Button) findViewById(R.id.copies_plus_button);
        LongTapRepeatAdapter.bless(this.copiesMinus);
        LongTapRepeatAdapter.bless(this.copiesPlus);
        this.colorInfo = (TextView) findViewById(R.id.color_info);
        this.duplexInfo = (TextView) findViewById(R.id.duplex_info);
        this.feedDirectionInfo = (TextView) findViewById(R.id.feed_direction_info);
        this.printDateInfo = (TextView) findViewById(R.id.printdate_info);
        this.brightness = (TextView) findViewById(R.id.brightness);
        this.brightnessMinus = (Button) findViewById(R.id.brightness_minus_button);
        this.brightnessPlus = (Button) findViewById(R.id.brightness_plus_button);
        this.contrast = (TextView) findViewById(R.id.contrast);
        this.contrastMinus = (Button) findViewById(R.id.contrast_minus_button);
        this.contrastPlus = (Button) findViewById(R.id.contrast_plus_button);
        this.saturation = (TextView) findViewById(R.id.saturation);
        this.saturationMinus = (Button) findViewById(R.id.saturation_minus_button);
        this.saturationPlus = (Button) findViewById(R.id.saturation_plus_button);
        this.progressGetOption = findViewById(R.id.progressGetOption);
        this.enableShowPreview = getSharedPreferences(Constants.PREFS_EPSON_CONNECT, 0).getBoolean(Constants.ENABLE_SHOW_PREVIEW, true);
        loadConfig();
        setClickListener();
        updatePrinterIcon();
        if (this.printerId != null) {
            this.undoFlag = false;
            if (loadSupportedMediaFile()) {
                this.mHandler.sendEmptyMessage(1);
            } else {
                this.mHandler.sendEmptyMessage(17);
            }
        } else {
            this.mHandler.sendEmptyMessage(1);
        }
    }

    private void updatePrinterIcon() {
        if (this.printerName.getText().equals(getString(R.string.str_lbl_title_scan))) {
            ((ImageView) findViewById(R.id.imageViewPrinterLocation)).setVisibility(8);
            return;
        }
        ((ImageView) findViewById(R.id.imageViewPrinterLocation)).setVisibility(0);
        switch (this.printerLocation) {
            case 1:
                ((ImageView) findViewById(R.id.imageViewPrinterLocation)).setImageResource(R.C2136drawable.print_local);
                return;
            case 2:
                ((ImageView) findViewById(R.id.imageViewPrinterLocation)).setImageResource(R.C2136drawable.print_remote);
                return;
            case 3:
                ((ImageView) findViewById(R.id.imageViewPrinterLocation)).setImageResource(R.C2136drawable.print_ip);
                return;
            default:
                return;
        }
    }

    private void setClickListener() {
        this.copiesMinus.setOnClickListener(this);
        this.copiesPlus.setOnClickListener(this);
        this.brightnessMinus.setOnClickListener(this);
        this.brightnessPlus.setOnClickListener(this);
        this.contrastMinus.setOnClickListener(this);
        this.contrastPlus.setOnClickListener(this);
        this.saturationMinus.setOnClickListener(this);
        this.saturationPlus.setOnClickListener(this);
        if (this.isDocumentSetting) {
            findViewById(R.id.page_range_setting).setOnClickListener(this);
        }
        findViewById(R.id.printer).setOnClickListener(this);
        findViewById(R.id.paper_size).setOnClickListener(this);
        findViewById(R.id.paper_type).setOnClickListener(this);
        findViewById(R.id.layout).setOnClickListener(this);
        findViewById(R.id.quality).setOnClickListener(this);
        findViewById(R.id.paper_source).setOnClickListener(this);
        findViewById(R.id.color).setOnClickListener(this);
        findViewById(R.id.duplex).setOnClickListener(this);
        findViewById(R.id.feed_direction).setOnClickListener(this);
        findViewById(R.id.printdate).setOnClickListener(this);
    }

    private void loadConfig() {
        MyPrinter curPrinter = MyPrinter.getCurPrinter(this);
        if (curPrinter == null || curPrinter.getName() == null) {
            this.printerName.setText(getString(R.string.str_lbl_title_scan));
        } else {
            this.printerName.setText(curPrinter.getUserDefName(this));
        }
        this.printerDeviceId = curPrinter.getName();
        this.printerId = curPrinter.getPrinterId();
        this.printerIp = curPrinter.getIp();
        this.printerSerialNo = curPrinter.getSerialNo();
        this.printerEmailAddress = curPrinter.getEmailAddress();
        this.printerLocation = curPrinter.getLocation();
        boolean z = true;
        if (this.printerLocation == 0) {
            this.printerLocation = 1;
        }
        this.autoConnectSsid = WiFiDirectManager.getConnectInfo(this, WiFiDirectManager.DEVICE_TYPE_PRINTER);
        PrintSetting printSetting = new PrintSetting(this, PrintSetting.Kind.cameracopy);
        printSetting.loadSettings();
        this.mLookupTable = new MediaInfo.PaperSize();
        this.paperSize = printSetting.paperSizeValue;
        this.paperSizeInfo.setText(getString(this.mLookupTable.getStringId(this.paperSize)));
        this.mLookupTable.destructor();
        this.mLookupTable = new MediaInfo.PaperType();
        this.paperType = printSetting.paperTypeValue;
        this.paperTypeInfo.setText(getString(this.mLookupTable.getStringId(this.paperType)));
        this.mLookupTable.destructor();
        this.mPaperSizeType = printSetting.loadPaperSizeTypePear();
        this.mPaperSizeType.putID(this.paperSize, this.paperType);
        this.mLookupTable = new MediaInfo.Layout();
        this.layout = printSetting.layoutValue;
        this.layoutInfo.setText(getString(this.mLookupTable.getStringId(this.layout)));
        this.mLookupTable.destructor();
        this.mLookupTable = new MediaInfo.Quality();
        this.quality = printSetting.qualityValue;
        this.qualityInfo.setText(getString(this.mLookupTable.getStringId(this.quality)));
        this.mLookupTable.destructor();
        this.mLookupTable = new MediaInfo.PaperSource();
        this.paperSource = printSetting.paperSourceValue;
        this.paperSourceInfo.setText(getString(this.mLookupTable.getStringId(this.paperSource)));
        this.mLookupTable.destructor();
        this.mLookupTable = new MediaInfo.Color();
        this.color = printSetting.colorValue;
        this.colorInfo.setText(getString(this.mLookupTable.getStringId(this.color)));
        this.mLookupTable.destructor();
        this.copiesValue = printSetting.copiesValue;
        this.copies.setText(String.valueOf(this.copiesValue));
        this.copiesMinus.setEnabled(this.copiesValue != 1);
        Button button = this.copiesPlus;
        if (this.copiesValue == 30) {
            z = false;
        }
        button.setEnabled(z);
        this.brightnessValue = printSetting.brightnessValue;
        this.contrastValue = printSetting.contrastValue;
        this.saturationValue = printSetting.saturationValue;
        this.mLookupTable = new MediaInfo.Duplex();
        this.duplex = printSetting.duplexValue;
        this.duplexInfo.setText(getString(this.mLookupTable.getStringId(this.duplex)));
        this.mLookupTable.destructor();
        this.mLookupTable = new MediaInfo.FeedDirection();
        this.feedDirection = printSetting.feedDirectionValue;
        this.feedDirectionInfo.setText(getString(this.mLookupTable.getStringId(this.feedDirection)));
        this.mLookupTable.destructor();
        this.lang = curPrinter.getLang();
        if (this.isDocumentSetting) {
            this.printAll = printSetting.printAll;
            this.startValue = printSetting.startValue;
            this.endValue = printSetting.endValue;
            ((TextView) findViewById(R.id.page_range_value)).setText(this.startValue + ".." + this.endValue);
            return;
        }
        this.mLookupTable = new MediaInfo.PrintDate();
        this.printdate = printSetting.printdate;
        this.printDateInfo.setText(getString(this.mLookupTable.getStringId(this.printdate)));
        this.mLookupTable.destructor();
    }

    private boolean loadSupportedMediaFile() {
        ExternalFileUtils instance = ExternalFileUtils.getInstance(this);
        File savedSupportedMedia = instance.getSavedSupportedMedia();
        File supportedMedia = instance.getSupportedMedia();
        File preSupportedMedia = instance.getPreSupportedMedia();
        EPLog.m313i(TAG, "call loadSupportedMedia");
        try {
            if (!savedSupportedMedia.exists()) {
                EPLog.m318w("loadSupportedMedia", savedSupportedMedia.getName() + " not exist");
                return false;
            }
            Utils.copyFile(savedSupportedMedia, supportedMedia);
            Utils.copyFile(savedSupportedMedia, preSupportedMedia);
            File savedAreaInfo = instance.getSavedAreaInfo();
            File areaInfo = instance.getAreaInfo();
            File preAreaInfo = instance.getPreAreaInfo();
            try {
                if (!savedAreaInfo.exists()) {
                    return true;
                }
                Utils.copyFile(savedAreaInfo, areaInfo);
                Utils.copyFile(savedAreaInfo, preAreaInfo);
                return true;
            } catch (Exception e) {
                EPLog.m318w("loadSupportedMedia", "failure " + e.getMessage());
                return false;
            }
        } catch (Exception e2) {
            EPLog.m318w("loadSupportedMedia", "failure " + e2.getMessage());
            return false;
        }
    }

    private boolean updateSupportedMediaFile(boolean z) {
        ExternalFileUtils instance = ExternalFileUtils.getInstance(this);
        EPLog.m313i(TAG, "call updateSupportedMedia");
        File supportedMedia = instance.getSupportedMedia();
        File preSupportedMedia = instance.getPreSupportedMedia();
        if (z) {
            File file = preSupportedMedia;
            preSupportedMedia = supportedMedia;
            supportedMedia = file;
        }
        try {
            Utils.copyFile(supportedMedia, preSupportedMedia);
            File areaInfo = instance.getAreaInfo();
            File preAreaInfo = instance.getPreAreaInfo();
            if (!z) {
                File file2 = areaInfo;
                areaInfo = preAreaInfo;
                preAreaInfo = file2;
            }
            try {
                if (!preAreaInfo.exists()) {
                    return true;
                }
                Utils.copyFile(preAreaInfo, areaInfo);
                return true;
            } catch (Exception e) {
                if (preAreaInfo != null && preAreaInfo.exists()) {
                    preAreaInfo.delete();
                }
                if (areaInfo != null && areaInfo.exists()) {
                    areaInfo.delete();
                }
                EPLog.m318w("updateSupportedMediaFile", "failure " + e.getMessage());
                return false;
            }
        } catch (Exception e2) {
            if (supportedMedia != null && supportedMedia.exists()) {
                supportedMedia.delete();
            }
            if (preSupportedMedia != null && preSupportedMedia.exists()) {
                preSupportedMedia.delete();
            }
            EPLog.m318w("updateSupportedMediaFile", "failure " + e2.getMessage());
            return false;
        }
    }

    private boolean saveSupportedMediaFile() {
        ExternalFileUtils instance = ExternalFileUtils.getInstance(this);
        EPLog.m313i(TAG, "call saveSupportedMedia");
        File supportedMedia = instance.getSupportedMedia();
        File savedSupportedMedia = instance.getSavedSupportedMedia();
        try {
            if (!supportedMedia.exists()) {
                EPLog.m318w("updateSupportedMediaFile", supportedMedia.getName() + " not exist");
                return false;
            }
            Utils.copyFile(supportedMedia, savedSupportedMedia);
            File areaInfo = instance.getAreaInfo();
            File savedAreaInfo = instance.getSavedAreaInfo();
            int i = this.printerLocation;
            if (i == 1 || i == 3) {
                try {
                    if (!areaInfo.exists()) {
                        EPLog.m318w("updateSupportedMediaFile", areaInfo.getName() + " not exist");
                        return false;
                    }
                    Utils.copyFile(areaInfo, savedAreaInfo);
                } catch (Exception e) {
                    EPLog.m318w("saveSupportedMediaFile", "failure " + e.getMessage());
                    return false;
                }
            } else {
                EPLog.m313i(TAG, "delete AreaInfo");
                instance.removeAreaInfo();
            }
            return true;
        } catch (Exception e2) {
            EPLog.m318w("saveSupportedMediaFile", "failure " + e2.getMessage());
            return false;
        }
    }

    private void saveChanged() {
        SharedPreferences.Editor edit = getSharedPreferences("PrintSetting", 0).edit();
        edit.putInt(Constants.PREFS_INFO_PRINT_SAVE, 1);
        edit.commit();
        MyPrinter myPrinter = new MyPrinter(this.printerDeviceId, this.printerIp, this.printerId, this.printerSerialNo, this.printerEmailAddress, this.printerLocation);
        myPrinter.setLang(this.lang);
        myPrinter.setCurPrinter(this);
        PrintSetting printSetting = new PrintSetting(this, PrintSetting.Kind.cameracopy);
        printSetting.paperSizeValue = this.paperSize;
        printSetting.paperTypeValue = this.paperType;
        printSetting.layoutValue = this.layout;
        printSetting.qualityValue = this.quality;
        printSetting.paperSourceValue = this.paperSource;
        printSetting.colorValue = this.color;
        printSetting.duplexValue = this.duplex;
        printSetting.feedDirectionValue = this.feedDirection;
        printSetting.copiesValue = this.copiesValue;
        printSetting.brightnessValue = this.brightnessValue;
        printSetting.contrastValue = this.contrastValue;
        printSetting.saturationValue = this.saturationValue;
        if (this.isDocumentSetting) {
            printSetting.printAll = this.printAll;
            printSetting.startValue = this.startValue;
            printSetting.endValue = this.endValue;
        } else {
            printSetting.printdate = this.printdate;
        }
        printSetting.saveSettings();
        printSetting.savePaperSizeTypePear((MediaInfo.PaperSizeType) this.mPaperSizeType);
        saveSupportedMediaFile();
        String str = this.autoConnectSsid;
        if (str == null || str.length() <= 0) {
            WiFiDirectManager.resetConnectInfo(this, WiFiDirectManager.DEVICE_TYPE_PRINTER);
        } else {
            WiFiDirectManager.setConnectInfo(this, this.autoConnectSsid, WiFiDirectManager.DEVICE_TYPE_PRINTER, myPrinter.getName());
        }
        EPPrinterManager ePPrinterManager = new EPPrinterManager(this.mContext);
        ePPrinterManager.commitIPPrinterInfo();
        ePPrinterManager.commitRemotePrinterInfo();
        if (this.mPrinterSelectDone) {
            new InkRplnRepository(false).savePermanently(this);
        }
    }

    protected void onDestroy() {
        super.onDestroy();
        unbindEpsonService();
        EPLog.m313i("SettingScr", "onDestroy");
        this.mPaperSizeType.destructor();
    }

    private void bindEpsonService() {
        EPLog.m316v("SettingScr", "bindEpsonService");
        if (this.mEpsonService == null) {
            bindService(new Intent(this, EpsonService.class), this.mEpsonConnection, 1);
        }
    }

    private void unbindEpsonService() {
        EPLog.m316v("SettingScr", "unbindEpsonService");
        IEpsonService iEpsonService = this.mEpsonService;
        if (iEpsonService != null) {
            try {
                iEpsonService.unregisterCallback(this.mCallback);
                unbindService(this.mEpsonConnection);
                this.mEpsonService = null;
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void onClick(View view) {
        if (this.progressGetOption.getVisibility() == 8) {
            IEpsonService iEpsonService = this.mEpsonService;
            if (iEpsonService != null) {
                try {
                    iEpsonService.cancelSearchPrinter();
                } catch (RemoteException e) {
                    e.printStackTrace();
                }
            }
            switch (view.getId()) {
                case R.id.brightness_minus_button /*2131230848*/:
                    this.brightnessValue--;
                    if (this.brightnessValue <= -50) {
                        this.brightnessValue = -50;
                        this.brightnessMinus.setEnabled(false);
                    } else {
                        this.brightnessMinus.setEnabled(true);
                    }
                    this.brightnessPlus.setEnabled(true);
                    this.brightness.setText(String.valueOf(this.brightnessValue));
                    return;
                case R.id.brightness_plus_button /*2131230850*/:
                    this.brightnessValue++;
                    if (this.brightnessValue >= 50) {
                        this.brightnessValue = 50;
                        this.brightnessPlus.setEnabled(false);
                    } else {
                        this.brightnessPlus.setEnabled(true);
                    }
                    this.brightnessMinus.setEnabled(true);
                    this.brightness.setText(String.valueOf(this.brightnessValue));
                    return;
                case R.id.color /*2131230930*/:
                    launchDetailScreen(this.color, R.id.color);
                    return;
                case R.id.contrast_minus_button /*2131230942*/:
                    this.contrastValue--;
                    if (this.contrastValue <= -50) {
                        this.contrastValue = -50;
                        this.contrastMinus.setEnabled(false);
                    } else {
                        this.contrastMinus.setEnabled(true);
                    }
                    this.contrastPlus.setEnabled(true);
                    this.contrast.setText(String.valueOf(this.contrastValue));
                    return;
                case R.id.contrast_plus_button /*2131230943*/:
                    this.contrastValue++;
                    if (this.contrastValue >= 50) {
                        this.contrastValue = 50;
                        this.contrastPlus.setEnabled(false);
                    } else {
                        this.contrastPlus.setEnabled(true);
                    }
                    this.contrastMinus.setEnabled(true);
                    this.contrast.setText(String.valueOf(this.contrastValue));
                    return;
                case R.id.copies_minus_button /*2131230945*/:
                    this.copiesValue--;
                    if (this.copiesValue <= 1) {
                        this.copiesValue = 1;
                        this.copiesMinus.setEnabled(false);
                    } else {
                        this.copiesMinus.setEnabled(true);
                    }
                    this.copiesPlus.setEnabled(true);
                    this.copies.setText(String.valueOf(this.copiesValue));
                    return;
                case R.id.copies_plus_button /*2131230946*/:
                    this.copiesValue++;
                    if (this.copiesValue >= 30) {
                        this.copiesValue = 30;
                        this.copiesPlus.setEnabled(false);
                    } else {
                        this.copiesPlus.setEnabled(true);
                    }
                    this.copiesMinus.setEnabled(true);
                    this.copies.setText(String.valueOf(this.copiesValue));
                    return;
                case R.id.duplex /*2131231005*/:
                    launchDetailScreen(this.duplex, R.id.duplex);
                    return;
                case R.id.feed_direction /*2131231037*/:
                    launchDetailScreen(this.feedDirection, R.id.feed_direction);
                    return;
                case R.id.layout /*2131231158*/:
                    launchDetailScreen(this.layout, R.id.layout);
                    return;
                case R.id.page_range_setting /*2131231300*/:
                    Intent intent = new Intent(this, PageRangeSetting.class);
                    intent.putExtra("SHEETS", this.sheets);
                    intent.putExtra("printAll", this.printAll);
                    intent.putExtra("startValue", this.startValue);
                    intent.putExtra("endValue", this.endValue);
                    startActivityForResult(intent, 2);
                    return;
                case R.id.paper_size /*2131231306*/:
                    launchDetailScreen(this.paperSize, R.id.paper_size);
                    return;
                case R.id.paper_source /*2131231311*/:
                    int i = this.paperSource;
                    int[] iArr = this.paper_source_info;
                    if (iArr != null && iArr.length <= 1) {
                        i = 128;
                    }
                    launchDetailScreen(i, R.id.paper_source);
                    return;
                case R.id.paper_type /*2131231314*/:
                    launchDetailScreen(this.paperType, R.id.paper_type);
                    return;
                case R.id.printdate /*2131231355*/:
                    launchDetailScreen(this.printdate, R.id.printdate);
                    return;
                case R.id.printer /*2131231358*/:
                    unbindEpsonService();
                    new AsyncTask<Void, Void, Void>() {
                        protected void onPreExecute() {
                            CameraPrintSettingActivity.this.findViewById(R.id.printer).setClickable(false);
                        }

                        protected Void doInBackground(Void... voidArr) {
                            CameraPrintSettingActivity cameraPrintSettingActivity = CameraPrintSettingActivity.this;
                            WiFiDirectManager.disconnect(cameraPrintSettingActivity, WiFiDirectManager.DEVICE_TYPE_PRINTER, cameraPrintSettingActivity.printerIp);
                            CameraPrintSettingActivity cameraPrintSettingActivity2 = CameraPrintSettingActivity.this;
                            WiFiDirectManager.disconnectSimpleAP(cameraPrintSettingActivity2, cameraPrintSettingActivity2.autoConnectSsid, CameraPrintSettingActivity.this.printerIp);
                            return null;
                        }

                        protected void onPostExecute(Void voidR) {
                            Intent intent = new Intent(CameraPrintSettingActivity.this, SearchPrinterScr.class);
                            Bundle bundle = new Bundle();
                            bundle.putString(Constants.PRINTER_ID, CameraPrintSettingActivity.this.printerId);
                            bundle.putString(Constants.PRINTER_IP, CameraPrintSettingActivity.this.printerIp);
                            bundle.putString(Constants.PRINTER_EMAIL_ADDRESS, CameraPrintSettingActivity.this.printerEmailAddress);
                            bundle.putInt(Constants.PRINTER_LOCATION, CameraPrintSettingActivity.this.printerLocation);
                            bundle.putString(CameraPrintSettingActivity.EXTRA_SIMPLEAP, CameraPrintSettingActivity.this.autoConnectSsid);
                            intent.putExtras(bundle);
                            CameraPrintSettingActivity.this.startActivityForResult(intent, 0);
                            CameraPrintSettingActivity.this.findViewById(R.id.printer).setClickable(true);
                        }
                    }.execute(new Void[0]);
                    return;
                case R.id.quality /*2131231392*/:
                    launchDetailScreen(this.quality, R.id.quality);
                    return;
                case R.id.saturation_minus_button /*2131231425*/:
                    this.saturationValue--;
                    if (this.saturationValue <= -50) {
                        this.saturationValue = -50;
                        this.saturationMinus.setEnabled(false);
                    } else {
                        this.saturationMinus.setEnabled(true);
                    }
                    this.saturationPlus.setEnabled(true);
                    this.saturation.setText(String.valueOf(this.saturationValue));
                    return;
                case R.id.saturation_plus_button /*2131231426*/:
                    this.saturationValue++;
                    if (this.saturationValue >= 50) {
                        this.saturationValue = 50;
                        this.saturationPlus.setEnabled(false);
                    } else {
                        this.saturationPlus.setEnabled(true);
                    }
                    this.saturationMinus.setEnabled(true);
                    this.saturation.setText(String.valueOf(this.saturationValue));
                    return;
                default:
                    return;
            }
        }
    }

    private void launchDetailScreen(int i, int i2) {
        Intent intent = new Intent(this, PrinterInfoDetail.class);
        Bundle bundle = new Bundle();
        bundle.putInt("ID", i2);
        bundle.putInt("sizeIndex", this.sizeIndex);
        bundle.putInt("typeIndex", this.typeIndex);
        bundle.putInt("curValue", i);
        bundle.putBoolean("isDocumentSetting", this.isDocumentSetting);
        switch (i2) {
            case R.id.color /*2131230930*/:
                bundle.putIntArray(Constants.COLOR_INFO, this.color_info);
                break;
            case R.id.duplex /*2131231005*/:
                bundle.putIntArray(Constants.DUPLEX_INFO, this.duplex_info);
                break;
            case R.id.layout /*2131231158*/:
                bundle.putIntArray(Constants.LAYOUT_INFO, this.layout_info);
                break;
            case R.id.paper_size /*2131231306*/:
                bundle.putIntArray(Constants.PAPER_SIZE_INFO, this.paper_size_info);
                break;
            case R.id.paper_source /*2131231311*/:
                int[] iArr = this.paper_source_info;
                bundle.putIntArray(Constants.PAPER_SOURCE_INFO, (iArr == null || iArr.length > 1) ? this.paper_source_info : new int[]{128});
                break;
            case R.id.paper_type /*2131231314*/:
                bundle.putIntArray(Constants.PAPER_TYPE_INFO, this.paper_type_info);
                break;
            case R.id.quality /*2131231392*/:
                bundle.putIntArray(Constants.PRINT_QUALITY_INFO, this.quality_info);
                break;
        }
        intent.putExtras(bundle);
        startActivityForResult(intent, 1);
    }

    protected void onActivityResult(int i, int i2, Intent intent) {
        super.onActivityResult(i, i2, intent);
        String callingPackage = getCallingPackage();
        EPLog.m313i(callingPackage, "requestCode = " + i + " resultCode = " + i2);
        if (i != 0) {
            if (i != 4) {
                if (i != 2) {
                    if (i == 1 && i2 == -1) {
                        int i3 = intent.getExtras().getInt("curValue");
                        switch (intent.getExtras().getInt("ID")) {
                            case R.id.color /*2131230930*/:
                                this.mLookupTable = new MediaInfo.Color();
                                this.colorInfo.setText(getString(this.mLookupTable.getStringId(i3)));
                                this.mLookupTable.destructor();
                                this.color = i3;
                                break;
                            case R.id.duplex /*2131231005*/:
                                this.mLookupTable = new MediaInfo.Duplex();
                                this.duplexInfo.setText(getString(this.mLookupTable.getStringId(i3)));
                                this.mLookupTable.destructor();
                                this.duplex = i3;
                                break;
                            case R.id.feed_direction /*2131231037*/:
                                this.mLookupTable = new MediaInfo.FeedDirection();
                                this.feedDirectionInfo.setText(getString(this.mLookupTable.getStringId(i3)));
                                this.mLookupTable.destructor();
                                this.feedDirection = i3;
                                break;
                            case R.id.layout /*2131231158*/:
                                this.mLookupTable = new MediaInfo.Layout();
                                this.layoutInfo.setText(getString(this.mLookupTable.getStringId(i3)));
                                this.mLookupTable.destructor();
                                this.layout = i3;
                                this.undoFlag = false;
                                this.mHandler.sendEmptyMessage(32);
                                break;
                            case R.id.paper_size /*2131231306*/:
                                this.sizeIndex = intent.getExtras().getInt("INDEX");
                                this.mLookupTable = new MediaInfo.PaperSize();
                                this.paperSizeInfo.setText(getString(this.mLookupTable.getStringId(i3)));
                                this.mLookupTable.destructor();
                                this.paperSize = i3;
                                this.paperType = this.mPaperSizeType.getID(this.paperSize);
                                this.undoFlag = false;
                                this.mHandler.sendEmptyMessage(2);
                                break;
                            case R.id.paper_source /*2131231311*/:
                                this.mLookupTable = new MediaInfo.PaperSource();
                                this.paperSourceInfo.setText(getString(this.mLookupTable.getStringId(i3)));
                                this.mLookupTable.destructor();
                                int[] iArr = this.paper_source_info;
                                if (iArr != null && iArr.length > 1) {
                                    this.paperSource = i3;
                                }
                                this.undoFlag = false;
                                this.mHandler.sendEmptyMessage(32);
                                break;
                            case R.id.paper_type /*2131231314*/:
                                this.typeIndex = intent.getExtras().getInt("INDEX");
                                this.mLookupTable = new MediaInfo.PaperType();
                                this.paperTypeInfo.setText(getString(this.mLookupTable.getStringId(i3)));
                                this.mLookupTable.destructor();
                                this.paperType = i3;
                                this.mPaperSizeType.putID(this.paperSize, this.paperType);
                                this.undoFlag = false;
                                this.mHandler.sendEmptyMessage(3);
                                break;
                            case R.id.printdate /*2131231355*/:
                                this.mLookupTable = new MediaInfo.PrintDate();
                                this.printDateInfo.setText(getString(this.mLookupTable.getStringId(i3)));
                                this.mLookupTable.destructor();
                                this.printdate = i3;
                                break;
                            case R.id.quality /*2131231392*/:
                                this.mLookupTable = new MediaInfo.Quality();
                                this.qualityInfo.setText(getString(this.mLookupTable.getStringId(i3)));
                                this.mLookupTable.destructor();
                                this.quality = i3;
                                break;
                        }
                    }
                } else if (i2 == -1) {
                    this.printAll = intent.getExtras().getBoolean("printAll");
                    this.startValue = intent.getExtras().getInt("startValue");
                    this.endValue = intent.getExtras().getInt("endValue");
                    this.mHandler.sendEmptyMessage(64);
                }
            } else {
                endInkReplAndGoProbePrinter();
            }
        } else {
            onPrinterSelectEnd(i2, intent);
        }
        updatePrinterIcon();
    }

    /* JADX WARNING: Can't fix incorrect switch cases order */
    /* JADX WARNING: Code restructure failed: missing block: B:25:0x00ea, code lost:
        if (r7.loadIpPrinterInfo(r6.printerId) == null) goto L_0x00f7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:27:0x00f3, code lost:
        if (r7.loadRemotePrinterInfo(r6.printerEmailAddress) == null) goto L_0x00f7;
     */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    private void onPrinterSelectEnd(int r7, android.content.Intent r8) {
        /*
            r6 = this;
            r0 = 0
            r1 = 1
            r2 = -1
            if (r7 != r2) goto L_0x00d6
            android.os.Bundle r7 = r8.getExtras()
            java.lang.String r2 = "myprinter"
            android.os.Parcelable r7 = r7.getParcelable(r2)
            epson.print.MyPrinter r7 = (epson.print.MyPrinter) r7
            r6.printer = r7
            android.widget.TextView r7 = r6.printerName
            epson.print.MyPrinter r2 = r6.printer
            java.lang.String r2 = r2.getName()
            r7.setText(r2)
            epson.print.MyPrinter r7 = r6.printer
            java.lang.String r7 = r7.getName()
            r6.printerDeviceId = r7
            epson.print.MyPrinter r7 = r6.printer
            java.lang.String r7 = r7.getPrinterId()
            r6.printerId = r7
            epson.print.MyPrinter r7 = r6.printer
            java.lang.String r7 = r7.getIp()
            r6.printerIp = r7
            epson.print.MyPrinter r7 = r6.printer
            java.lang.String r7 = r7.getSerialNo()
            r6.printerSerialNo = r7
            epson.print.MyPrinter r7 = r6.printer
            java.lang.String r7 = r7.getEmailAddress()
            r6.printerEmailAddress = r7
            epson.print.MyPrinter r7 = r6.printer
            int r7 = r7.getLocation()
            r6.printerLocation = r7
            epson.print.EPPrinterManager r7 = new epson.print.EPPrinterManager
            r7.<init>(r6)
            int r2 = r6.printerLocation
            switch(r2) {
                case 2: goto L_0x0075;
                case 3: goto L_0x0059;
                default: goto L_0x0058;
            }
        L_0x0058:
            goto L_0x0090
        L_0x0059:
            java.lang.String r2 = r6.printerId
            epson.print.EPPrinterInfo r7 = r7.loadIpPrinterInfo(r2)
            if (r7 == 0) goto L_0x0090
            java.lang.String r2 = r7.userDefName
            if (r2 == 0) goto L_0x0090
            java.lang.String r2 = r7.userDefName
            int r2 = r2.length()
            if (r2 <= 0) goto L_0x0090
            android.widget.TextView r2 = r6.printerName
            java.lang.String r7 = r7.userDefName
            r2.setText(r7)
            goto L_0x0090
        L_0x0075:
            java.lang.String r2 = r6.printerEmailAddress
            epson.print.EPPrinterInfo r7 = r7.loadRemotePrinterInfo(r2)
            if (r7 == 0) goto L_0x0090
            java.lang.String r2 = r7.userDefName
            if (r2 == 0) goto L_0x0090
            java.lang.String r2 = r7.userDefName
            int r2 = r2.length()
            if (r2 <= 0) goto L_0x0090
            android.widget.TextView r2 = r6.printerName
            java.lang.String r7 = r7.userDefName
            r2.setText(r7)
        L_0x0090:
            android.os.Bundle r7 = r8.getExtras()
            java.lang.String r8 = "simpleap"
            java.lang.String r7 = r7.getString(r8)
            r6.autoConnectSsid = r7
            android.content.Context r7 = r6.getApplicationContext()
            java.lang.String r8 = "PrintSetting"
            java.lang.String r2 = "RE_SEARCH"
            epson.common.Utils.savePref((android.content.Context) r7, (java.lang.String) r8, (java.lang.String) r2, (boolean) r1)
            r6.undoFlag = r0
            r6.mPrinterSelectDone = r1
            r6.mWaiteInkReplenProgress = r1
            android.content.Context r7 = r6.getApplicationContext()
            java.lang.String r8 = r6.printerId
            boolean r7 = epson.print.inkrpln.InkReplnHelper.isSimpleApOrP2p(r7, r8)
            if (r7 != 0) goto L_0x00d2
            epson.print.inkrpln.PrintSettingDependencyBuilder r7 = new epson.print.inkrpln.PrintSettingDependencyBuilder
            java.lang.String r1 = r6.printerId
            java.lang.String r2 = r6.printerIp
            java.lang.String r3 = r6.printerSerialNo
            int r4 = r6.printerLocation
            java.lang.String r5 = r6.printerDeviceId
            r0 = r7
            r0.<init>(r1, r2, r3, r4, r5)
            android.content.Intent r7 = epson.print.inkrpln.InkRplnProgressDialog.getStartIntent2(r6, r7)
            r8 = 4
            r6.startActivityForResult(r7, r8)
            goto L_0x00fc
        L_0x00d2:
            r6.endInkReplAndGoProbePrinter()
            goto L_0x00fc
        L_0x00d6:
            r6.bindEpsonService()
            epson.print.EPPrinterManager r7 = new epson.print.EPPrinterManager
            r7.<init>(r6)
            int r8 = r6.printerLocation
            switch(r8) {
                case 2: goto L_0x00ed;
                case 3: goto L_0x00e4;
                default: goto L_0x00e3;
            }
        L_0x00e3:
            goto L_0x00f6
        L_0x00e4:
            java.lang.String r8 = r6.printerId
            epson.print.EPPrinterInfo r7 = r7.loadIpPrinterInfo(r8)
            if (r7 != 0) goto L_0x00f6
            goto L_0x00f7
        L_0x00ed:
            java.lang.String r8 = r6.printerEmailAddress
            epson.print.EPPrinterInfo r7 = r7.loadRemotePrinterInfo(r8)
            if (r7 != 0) goto L_0x00f6
            goto L_0x00f7
        L_0x00f6:
            r1 = 0
        L_0x00f7:
            if (r1 == 0) goto L_0x00fc
            r6.resetSettings()
        L_0x00fc:
            return
        */
        throw new UnsupportedOperationException("Method not decompiled: com.epson.cameracopy.p006ui.CameraPrintSettingActivity.onPrinterSelectEnd(int, android.content.Intent):void");
    }

    private void endInkReplAndGoProbePrinter() {
        this.mWaiteInkReplenProgress = false;
        bindEpsonService();
        this.mHandler.sendEmptyMessageDelayed(17, 100);
    }

    private void updateSettingView() {
        boolean z = this.isDocumentSetting;
        setVisibilityPageRange(false);
        int[] iArr = this.color_info;
        if (iArr == null) {
            ((ImageView) findViewById(R.id.color_next_screen_imv)).setVisibility(8);
        } else if (iArr.length <= 1) {
            ((ImageView) findViewById(R.id.color_next_screen_imv)).setVisibility(8);
        } else {
            ((ImageView) findViewById(R.id.color_next_screen_imv)).setVisibility(0);
        }
        int[] iArr2 = this.duplex_info;
        findViewById(R.id.duplex_view).setVisibility(8);
        ((LinearLayout) findViewById(R.id.duplex)).setVisibility(8);
        switch (this.lang) {
            case 2:
            case 3:
                findViewById(R.id.feed_direction_view).setVisibility(0);
                findViewById(R.id.feed_direction).setVisibility(0);
                break;
            default:
                findViewById(R.id.feed_direction_view).setVisibility(8);
                findViewById(R.id.feed_direction).setVisibility(8);
                break;
        }
        if (!this.isDocumentSetting) {
            int i = this.printerLocation;
        }
        findViewById(R.id.printdate).setVisibility(8);
    }

    private int getPrinterLang() {
        int i;
        IEpsonService iEpsonService;
        if (!(this.printerLocation == 2 || (iEpsonService = this.mEpsonService) == null)) {
            try {
                i = iEpsonService.getLang();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
            EPLog.m305d(TAG, "getPrinterLang called : ret = " + i);
            return i;
        }
        i = 1;
        EPLog.m305d(TAG, "getPrinterLang called : ret = " + i);
        return i;
    }

    private void setVisibilityPageRange(boolean z) {
        int i = 0;
        findViewById(R.id.page_range_setting).setVisibility(z ? 0 : 8);
        View findViewById = findViewById(R.id.page_range_separator);
        if (!z) {
            i = 8;
        }
        findViewById.setVisibility(i);
    }

    private void setClickablePageRange(boolean z) {
        findViewById(R.id.page_range_setting).setClickable(z);
        int i = 0;
        findViewById(R.id.page_range_next_screen_imv).setVisibility(z ? 0 : 8);
        View findViewById = findViewById(R.id.page_range_value);
        if (!z) {
            i = 8;
        }
        findViewById.setVisibility(i);
    }

    private void resetSettings() {
        this.printerDeviceId = null;
        this.printerId = null;
        this.printerEmailAddress = null;
        this.printerIp = null;
        this.printerLocation = 0;
        this.info = null;
        this.paper_source_info = null;
        this.color_info = null;
        this.paper_size_info = null;
        this.paper_type_info = null;
        this.layout_info = null;
        this.quality_info = null;
        this.duplex_info = null;
        this.autoConnectSsid = "";
        this.printerName.setText(getString(R.string.str_lbl_title_scan));
        ((ImageView) findViewById(R.id.imageViewPrinterLocation)).setVisibility(8);
        updateSettingView();
        setScreenState(true);
    }

    public void onBackPressed() {
        super.onBackPressed();
        IEpsonService iEpsonService = this.mEpsonService;
        if (iEpsonService != null) {
            try {
                iEpsonService.cancelSearchPrinter();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        loadSupportedMediaFile();
        EPPrinterManager ePPrinterManager = new EPPrinterManager(this.mContext);
        ePPrinterManager.rollbackRemotePrinterInfo();
        ePPrinterManager.rollbackIPPrinterInfo();
        new InkRplnRepository(false).deleteTemporaryData(this);
    }

    private void setScreenState(Boolean bool) {
        if (bool.booleanValue()) {
            this.progressGetOption.setVisibility(8);
        } else {
            this.progressGetOption.setVisibility(0);
        }
        findViewById(R.id.printer).setClickable(bool.booleanValue());
        findViewById(R.id.paper_size).setClickable(bool.booleanValue());
        findViewById(R.id.paper_type).setClickable(bool.booleanValue());
        findViewById(R.id.layout).setClickable(bool.booleanValue());
        findViewById(R.id.quality).setClickable(bool.booleanValue());
        findViewById(R.id.paper_source).setClickable(bool.booleanValue());
        findViewById(R.id.color).setClickable(bool.booleanValue());
        findViewById(R.id.duplex).setClickable(bool.booleanValue());
        findViewById(R.id.feed_direction).setClickable(bool.booleanValue());
        findViewById(R.id.printdate).setClickable(bool.booleanValue());
    }

    public void showErrorDialog(String str, String str2) {
        new CustomTitleAlertDialogBuilder(this).setCancelable(false).setTitle(str).setMessage(str2).setNegativeButton(getString(R.string.ok_button), new DialogInterface.OnClickListener() {
            public void onClick(DialogInterface dialogInterface, int i) {
                CameraPrintSettingActivity.this.setScreenState(true);
                dialogInterface.cancel();
            }
        }).create().show();
        updateSupportedMediaFile(true);
    }

    protected void onResume() {
        super.onResume();
        EPLog.m307e("SettingScr", "onResume()");
        if (this.printerId != null && this.printerLocation == 1 && this.isRetryAfterConnectSimpleAp) {
            this.undoFlag = false;
            if (loadSupportedMediaFile()) {
                this.mHandler.sendEmptyMessage(1);
            } else {
                this.mHandler.sendEmptyMessage(17);
            }
        }
    }

    protected void onPause() {
        EPLog.m305d("SettingScr", "onPause");
        super.onPause();
        if (isFinishing()) {
            deleteLongTapMessage();
        }
        WiFiDirectManager.disconnect(this, WiFiDirectManager.DEVICE_TYPE_PRINTER, this.printerIp);
        WiFiDirectManager.disconnectSimpleAP(this, this.autoConnectSsid, this.printerIp);
    }

    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.C2138menu.menu_done, menu);
        return super.onCreateOptionsMenu(menu);
    }

    public boolean onOptionsItemSelected(MenuItem menuItem) {
        if (menuItem.getItemId() != R.id.menuSettingsDone) {
            return super.onOptionsItemSelected(menuItem);
        }
        saveChanged();
        setResult(3, getIntent());
        finish();
        return true;
    }

    protected void deleteLongTapMessage() {
        MotionEvent obtain = MotionEvent.obtain(SystemClock.uptimeMillis(), SystemClock.uptimeMillis() + 10, 1, 0.0f, 0.0f, 0);
        this.copiesMinus.dispatchTouchEvent(obtain);
        this.copiesPlus.dispatchTouchEvent(obtain);
    }

    public void onConfigurationChanged(Configuration configuration) {
        super.onConfigurationChanged(configuration);
        deleteLongTapMessage();
    }
}
