package epson.scan.lib;

import android.content.Context;

import epson.print.R;
import java.io.Serializable;

public class ScannerInfo implements Serializable {
    private int adfPaperGuide = 0;
    private int colorValue;
    private String commonDeviceName;
    private boolean densityStatus;
    private int densityValue;
    private String friendlyName;
    private int gammaValue;

    /* renamed from: ip */
    private String f413ip;
    private boolean isAdfDuplexRotaitonYes = false;
    private boolean isAdfDuplexYes = false;
    private boolean isReSearch;
    private int location;
    private int maxHeight;
    private int maxWidth;
    private String modelName;
    private int resolutionValue;
    private String scannerId;
    private int sizeValue;
    private int sourceValue;
    private int supportedAdfDuplex;
    private int supportedAdfHeight;
    private int supportedAdfWidth;
    private int supportedBasicHeight;
    private int supportedBasicResolution;
    private int supportedBasicWidth;
    private int[] supportedOptions;
    private int[] supportedResolutionList;
    private int supportedVersion;
    private int twoSidedScanningValue;
    private int version;

    public ScannerInfo() {
    }

    public ScannerInfo(ScannerInfo scannerInfo) {
        this.modelName = scannerInfo.getModelName();
        this.f413ip = scannerInfo.getIp();
        this.friendlyName = scannerInfo.getFriendlyName();
        this.scannerId = scannerInfo.getScannerId();
        this.colorValue = scannerInfo.getColorValue();
        this.densityStatus = scannerInfo.densityStatus;
        this.densityValue = scannerInfo.densityValue;
        this.gammaValue = scannerInfo.getGammaValue();
        this.sizeValue = scannerInfo.getSizeValue();
        this.isReSearch = scannerInfo.isReSearch();
        this.maxHeight = scannerInfo.getMaxHeight();
        this.maxWidth = scannerInfo.getMaxWidth();
        this.resolutionValue = scannerInfo.getResolutionValue();
        this.sourceValue = scannerInfo.getSourceValue();
        this.supportedAdfDuplex = scannerInfo.getSupportedAdfDuplex();
        this.supportedAdfHeight = scannerInfo.getSupportedAdfHeight();
        this.supportedAdfWidth = scannerInfo.getSupportedAdfWidth();
        this.supportedBasicHeight = scannerInfo.getSupportedBasicHeight();
        this.supportedBasicResolution = scannerInfo.getSupportedBasicResolution();
        this.supportedBasicWidth = scannerInfo.getSupportedBasicWidth();
        this.supportedOptions = scannerInfo.getSupportedOptions();
        this.supportedResolutionList = scannerInfo.getSupportedResolutionList();
        this.supportedVersion = scannerInfo.getSupportedVersion();
        this.twoSidedScanningValue = scannerInfo.getTwoSidedScanningValue();
        this.isAdfDuplexYes = scannerInfo.isAdfDuplexYes();
        this.isAdfDuplexRotaitonYes = scannerInfo.isAdfDuplexRotaitonYes();
        this.adfPaperGuide = scannerInfo.getAdfPaperGuide();
    }

    public String getModelName() {
        return this.modelName;
    }

    public boolean isModelNameEmpty() {
        String str = this.modelName;
        return str == null || str.isEmpty();
    }

    public void setModelName(String str) {
        this.modelName = str;
    }

    public String getIp() {
        return this.f413ip;
    }

    public void setIp(String str) {
        this.f413ip = str;
    }

    public String getFriendlyName() {
        return this.friendlyName;
    }

    public void setFriendlyName(String str) {
        this.friendlyName = str;
    }

    public String getScannerId() {
        return this.scannerId;
    }

    public void setScannerId(String str) {
        this.scannerId = str;
    }

    public String getCommonDeviceName() {
        return this.commonDeviceName;
    }

    public void setCommonDeviceName(String str) {
        this.commonDeviceName = str;
    }

    public int getLocation() {
        return this.location;
    }

    public void setLocation(int i) {
        this.location = i;
    }

    public int[] getSupportedOptions() {
        return this.supportedOptions;
    }

    public void setSupportedOptions(int[] iArr) {
        this.supportedOptions = iArr;
    }

    public int getVersion() {
        return this.version;
    }

    public void setVersion(int i) {
        this.version = i;
    }

    public String getResolutionName(Context context) {
        int resolutionValue2 = getResolutionValue();
        if (resolutionValue2 == 0) {
            return context.getString(R.string.str_blank);
        }
        return String.format(context.getString(R.string.str_settings_resolution), new Object[]{Integer.valueOf(resolutionValue2)});
    }

    public int getResolutionValue() {
        return this.resolutionValue;
    }

    public void setResolutionValue(int i) {
        this.resolutionValue = i;
    }

    public int getColorName() {
        switch (getColorValue()) {
            case 1:
                return R.string.str_settings_color_color;
            case 2:
                return R.string.str_settings_color_grayscale;
            case 3:
                return R.string.str_settings_color_monochrome;
            default:
                return R.string.str_blank;
        }
    }

    public int getColorValue() {
        return this.colorValue;
    }

    public void setColorValue(int i) {
        this.colorValue = i;
    }

    public int getSourceName() {
        switch (getSourceValue()) {
            case 0:
                return R.string.str_settings_source_doctable;
            case 1:
                return R.string.str_settings_source_adf;
            default:
                return R.string.str_blank;
        }
    }

    public int getSourceValue() {
        return this.sourceValue;
    }

    public void setSourceValue(int i) {
        this.sourceValue = i;
    }

    public int getTwoSidedScanningName() {
        switch (getTwoSidedScanningValue()) {
            case 0:
                return R.string.str_no;
            case 1:
                return R.string.str_yes;
            default:
                return R.string.str_blank;
        }
    }

    public int getTwoSidedScanningValue() {
        return this.twoSidedScanningValue;
    }

    public void setTwoSidedScanningValue(int i) {
        this.twoSidedScanningValue = i;
    }

    public int getDensityValue() {
        return this.densityValue;
    }

    public void setDensityValue(int i) {
        this.densityValue = i;
    }

    public boolean isDensityStatus() {
        return this.densityStatus;
    }

    public void setDensityStatus(boolean z) {
        this.densityStatus = z;
    }

    public int getGammaName() {
        switch (getGammaValue()) {
            case 0:
                return R.string.str_settings_gamma_10;
            case 1:
                return R.string.str_settings_gamma_18;
            default:
                return R.string.str_blank;
        }
    }

    public int getGammaValue() {
        return this.gammaValue;
    }

    public void setGammaValue(int i) {
        this.gammaValue = i;
    }

    public int getSizeValue() {
        return this.sizeValue;
    }

    public void setSizeValue(int i) {
        this.sizeValue = i;
    }

    public int getSupportedVersion() {
        return this.supportedVersion;
    }

    public void setSupportedVersion(int i) {
        this.supportedVersion = i;
    }

    public int getSupportedBasicResolution() {
        return this.supportedBasicResolution;
    }

    public void setSupportedBasicResolution(int i) {
        this.supportedBasicResolution = i;
    }

    public int getSupportedBasicHeight() {
        return this.supportedBasicHeight;
    }

    public void setSupportedBasicHeight(int i) {
        this.supportedBasicHeight = i;
    }

    public int getSupportedBasicWidth() {
        return this.supportedBasicWidth;
    }

    public void setSupportedBasicWidth(int i) {
        this.supportedBasicWidth = i;
    }

    public int getSupportedAdfHeight() {
        return this.supportedAdfHeight;
    }

    public void setSupportedAdfHeight(int i) {
        this.supportedAdfHeight = i;
    }

    public int getSupportedAdfWidth() {
        return this.supportedAdfWidth;
    }

    public void setSupportedAdfWidth(int i) {
        this.supportedAdfWidth = i;
    }

    public int getSupportedAdfDuplex() {
        return this.supportedAdfDuplex;
    }

    public void setSupportedAdfDuplex(int i) {
        this.supportedAdfDuplex = i;
    }

    public int[] getSupportedResolutionList() {
        return this.supportedResolutionList;
    }

    public void setSupportedResolutionList(int[] iArr) {
        this.supportedResolutionList = iArr;
    }

    public boolean isReSearch() {
        return this.isReSearch;
    }

    public void setReSearch(boolean z) {
        this.isReSearch = z;
    }

    public int getMaxWidth() {
        return this.maxWidth;
    }

    public void setMaxWidth(int i) {
        this.maxWidth = i;
    }

    public int getMaxHeight() {
        return this.maxHeight;
    }

    public void setMaxHeight(int i) {
        this.maxHeight = i;
    }

    public boolean isAdfDuplexYes() {
        return this.isAdfDuplexYes;
    }

    public void setAdfDuplexYes(boolean z) {
        this.isAdfDuplexYes = z;
    }

    public boolean isAdfDuplexRotaitonYes() {
        return this.isAdfDuplexRotaitonYes;
    }

    public void setAdfDuplexRotaitonYes(boolean z) {
        this.isAdfDuplexRotaitonYes = z;
    }

    public int getAdfPaperGuide() {
        return this.adfPaperGuide;
    }

    public void setAdfPaperGuide(int i) {
        this.adfPaperGuide = i;
    }

    @NonNull
    public static ScannerInfo getInstance() {
        ScannerInfo scannerInfo = new ScannerInfo();
        scannerInfo.setScannerId("");
        scannerInfo.setIp("");
        scannerInfo.setModelName("");
        scannerInfo.setLocation(1);
        scannerInfo.setCommonDeviceName("");
        scannerInfo.setSupportedOptions(new int[7]);
        scannerInfo.setSupportedResolutionList(new int[64]);
        return scannerInfo;
    }
}
